# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.gogo.protobuf.gogoproto import gogo_pb2 as github_dot_com_dot_gogo_dot_protobuf_dot_gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='api.proto',
  package='runtime',
  syntax='proto3',
  serialized_pb=_b('\n\tapi.proto\x12\x07runtime\x1a-github.com/gogo/protobuf/gogoproto/gogo.proto\"!\n\x0eVersionRequest\x12\x0f\n\x07version\x18\x01 \x01(\t\"n\n\x0fVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x14\n\x0cruntime_name\x18\x02 \x01(\t\x12\x17\n\x0fruntime_version\x18\x03 \x01(\t\x12\x1b\n\x13runtime_api_version\x18\x04 \x01(\t\"?\n\tDNSConfig\x12\x0f\n\x07servers\x18\x01 \x03(\t\x12\x10\n\x08searches\x18\x02 \x03(\t\x12\x0f\n\x07options\x18\x03 \x03(\t\"n\n\x0bPortMapping\x12#\n\x08protocol\x18\x01 \x01(\x0e\x32\x11.runtime.Protocol\x12\x16\n\x0e\x63ontainer_port\x18\x02 \x01(\x05\x12\x11\n\thost_port\x18\x03 \x01(\x05\x12\x0f\n\x07host_ip\x18\x04 \x01(\t\"]\n\x05Mount\x12\x16\n\x0e\x63ontainer_path\x18\x01 \x01(\t\x12\x11\n\thost_path\x18\x02 \x01(\t\x12\x10\n\x08readonly\x18\x03 \x01(\x08\x12\x17\n\x0fselinux_relabel\x18\x04 \x01(\x08\"K\n\x0fNamespaceOption\x12\x14\n\x0chost_network\x18\x01 \x01(\x08\x12\x10\n\x08host_pid\x18\x02 \x01(\x08\x12\x10\n\x08host_ipc\x18\x03 \x01(\x08\"\x1b\n\nInt64Value\x12\r\n\x05value\x18\x01 \x01(\x03\"\xf7\x01\n\x1bLinuxSandboxSecurityContext\x12\x33\n\x11namespace_options\x18\x01 \x01(\x0b\x32\x18.runtime.NamespaceOption\x12/\n\x0fselinux_options\x18\x02 \x01(\x0b\x32\x16.runtime.SELinuxOption\x12(\n\x0brun_as_user\x18\x03 \x01(\x0b\x32\x13.runtime.Int64Value\x12\x17\n\x0freadonly_rootfs\x18\x04 \x01(\x08\x12\x1b\n\x13supplemental_groups\x18\x05 \x03(\x03\x12\x12\n\nprivileged\x18\x06 \x01(\x08\"n\n\x15LinuxPodSandboxConfig\x12\x15\n\rcgroup_parent\x18\x01 \x01(\t\x12>\n\x10security_context\x18\x02 \x01(\x0b\x32$.runtime.LinuxSandboxSecurityContext\"S\n\x12PodSandboxMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0f\n\x07\x61ttempt\x18\x04 \x01(\r\"\xc9\x03\n\x10PodSandboxConfig\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.runtime.PodSandboxMetadata\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x15\n\rlog_directory\x18\x03 \x01(\t\x12&\n\ndns_config\x18\x04 \x01(\x0b\x32\x12.runtime.DNSConfig\x12+\n\rport_mappings\x18\x05 \x03(\x0b\x32\x14.runtime.PortMapping\x12\x35\n\x06labels\x18\x06 \x03(\x0b\x32%.runtime.PodSandboxConfig.LabelsEntry\x12?\n\x0b\x61nnotations\x18\x07 \x03(\x0b\x32*.runtime.PodSandboxConfig.AnnotationsEntry\x12-\n\x05linux\x18\x08 \x01(\x0b\x32\x1e.runtime.LinuxPodSandboxConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n\x14RunPodSandboxRequest\x12)\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x19.runtime.PodSandboxConfig\"/\n\x15RunPodSandboxResponse\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\"/\n\x15StopPodSandboxRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\"\x18\n\x16StopPodSandboxResponse\"1\n\x17RemovePodSandboxRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\"\x1a\n\x18RemovePodSandboxResponse\"1\n\x17PodSandboxStatusRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\"%\n\x17PodSandboxNetworkStatus\x12\n\n\x02ip\x18\x01 \x01(\t\"G\n\tNamespace\x12\x0f\n\x07network\x18\x01 \x01(\t\x12)\n\x07options\x18\x02 \x01(\x0b\x32\x18.runtime.NamespaceOption\"?\n\x15LinuxPodSandboxStatus\x12&\n\nnamespaces\x18\x01 \x01(\x0b\x32\x12.runtime.Namespace\"\xc7\x03\n\x10PodSandboxStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\x08metadata\x18\x02 \x01(\x0b\x32\x1b.runtime.PodSandboxMetadata\x12\'\n\x05state\x18\x03 \x01(\x0e\x32\x18.runtime.PodSandboxState\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12\x31\n\x07network\x18\x05 \x01(\x0b\x32 .runtime.PodSandboxNetworkStatus\x12-\n\x05linux\x18\x06 \x01(\x0b\x32\x1e.runtime.LinuxPodSandboxStatus\x12\x35\n\x06labels\x18\x07 \x03(\x0b\x32%.runtime.PodSandboxStatus.LabelsEntry\x12?\n\x0b\x61nnotations\x18\x08 \x03(\x0b\x32*.runtime.PodSandboxStatus.AnnotationsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\x18PodSandboxStatusResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x19.runtime.PodSandboxStatus\"?\n\x14PodSandboxStateValue\x12\'\n\x05state\x18\x01 \x01(\x0e\x32\x18.runtime.PodSandboxState\"\xc8\x01\n\x10PodSandboxFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n\x05state\x18\x02 \x01(\x0b\x32\x1d.runtime.PodSandboxStateValue\x12\x44\n\x0elabel_selector\x18\x03 \x03(\x0b\x32,.runtime.PodSandboxFilter.LabelSelectorEntry\x1a\x34\n\x12LabelSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"B\n\x15ListPodSandboxRequest\x12)\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x19.runtime.PodSandboxFilter\"\xd3\x02\n\nPodSandbox\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\x08metadata\x18\x02 \x01(\x0b\x32\x1b.runtime.PodSandboxMetadata\x12\'\n\x05state\x18\x03 \x01(\x0e\x32\x18.runtime.PodSandboxState\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12/\n\x06labels\x18\x05 \x03(\x0b\x32\x1f.runtime.PodSandbox.LabelsEntry\x12\x39\n\x0b\x61nnotations\x18\x06 \x03(\x0b\x32$.runtime.PodSandbox.AnnotationsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x16ListPodSandboxResponse\x12\"\n\x05items\x18\x01 \x03(\x0b\x32\x13.runtime.PodSandbox\"\x1a\n\tImageSpec\x12\r\n\x05image\x18\x01 \x01(\t\"&\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x8a\x01\n\x17LinuxContainerResources\x12\x12\n\ncpu_period\x18\x01 \x01(\x03\x12\x11\n\tcpu_quota\x18\x02 \x01(\x03\x12\x12\n\ncpu_shares\x18\x03 \x01(\x03\x12\x1d\n\x15memory_limit_in_bytes\x18\x04 \x01(\x03\x12\x15\n\room_score_adj\x18\x05 \x01(\x03\"H\n\rSELinuxOption\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\"A\n\nCapability\x12\x18\n\x10\x61\x64\x64_capabilities\x18\x01 \x03(\t\x12\x19\n\x11\x64rop_capabilities\x18\x02 \x03(\t\"\xbd\x02\n\x1dLinuxContainerSecurityContext\x12)\n\x0c\x63\x61pabilities\x18\x01 \x01(\x0b\x32\x13.runtime.Capability\x12\x12\n\nprivileged\x18\x02 \x01(\x08\x12\x33\n\x11namespace_options\x18\x03 \x01(\x0b\x32\x18.runtime.NamespaceOption\x12/\n\x0fselinux_options\x18\x04 \x01(\x0b\x32\x16.runtime.SELinuxOption\x12(\n\x0brun_as_user\x18\x05 \x01(\x0b\x32\x13.runtime.Int64Value\x12\x17\n\x0frun_as_username\x18\x06 \x01(\t\x12\x17\n\x0freadonly_rootfs\x18\x07 \x01(\x08\x12\x1b\n\x13supplemental_groups\x18\x08 \x03(\x03\"\x8d\x01\n\x14LinuxContainerConfig\x12\x33\n\tresources\x18\x01 \x01(\x0b\x32 .runtime.LinuxContainerResources\x12@\n\x10security_context\x18\x02 \x01(\x0b\x32&.runtime.LinuxContainerSecurityContext\"2\n\x11\x43ontainerMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61ttempt\x18\x02 \x01(\r\"H\n\x06\x44\x65vice\x12\x16\n\x0e\x63ontainer_path\x18\x01 \x01(\t\x12\x11\n\thost_path\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x01(\t\"\xc2\x04\n\x0f\x43ontainerConfig\x12,\n\x08metadata\x18\x01 \x01(\x0b\x32\x1a.runtime.ContainerMetadata\x12!\n\x05image\x18\x02 \x01(\x0b\x32\x12.runtime.ImageSpec\x12\x0f\n\x07\x63ommand\x18\x03 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x04 \x03(\t\x12\x13\n\x0bworking_dir\x18\x05 \x01(\t\x12\x1f\n\x04\x65nvs\x18\x06 \x03(\x0b\x32\x11.runtime.KeyValue\x12\x1e\n\x06mounts\x18\x07 \x03(\x0b\x32\x0e.runtime.Mount\x12 \n\x07\x64\x65vices\x18\x08 \x03(\x0b\x32\x0f.runtime.Device\x12\x34\n\x06labels\x18\t \x03(\x0b\x32$.runtime.ContainerConfig.LabelsEntry\x12>\n\x0b\x61nnotations\x18\n \x03(\x0b\x32).runtime.ContainerConfig.AnnotationsEntry\x12\x10\n\x08log_path\x18\x0b \x01(\t\x12\r\n\x05stdin\x18\x0c \x01(\x08\x12\x12\n\nstdin_once\x18\r \x01(\x08\x12\x0b\n\x03tty\x18\x0e \x01(\x08\x12,\n\x05linux\x18\x0f \x01(\x0b\x32\x1d.runtime.LinuxContainerConfig\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x16\x43reateContainerRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\x12(\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x18.runtime.ContainerConfig\x12\x31\n\x0esandbox_config\x18\x03 \x01(\x0b\x32\x19.runtime.PodSandboxConfig\"/\n\x17\x43reateContainerResponse\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"-\n\x15StartContainerRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"\x18\n\x16StartContainerResponse\"=\n\x14StopContainerRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\x03\"\x17\n\x15StopContainerResponse\".\n\x16RemoveContainerRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"\x19\n\x17RemoveContainerResponse\"=\n\x13\x43ontainerStateValue\x12&\n\x05state\x18\x01 \x01(\x0e\x32\x17.runtime.ContainerState\"\xdd\x01\n\x0f\x43ontainerFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\x05state\x18\x02 \x01(\x0b\x32\x1c.runtime.ContainerStateValue\x12\x16\n\x0epod_sandbox_id\x18\x03 \x01(\t\x12\x43\n\x0elabel_selector\x18\x04 \x03(\x0b\x32+.runtime.ContainerFilter.LabelSelectorEntry\x1a\x34\n\x12LabelSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"A\n\x15ListContainersRequest\x12(\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x18.runtime.ContainerFilter\"\x9c\x03\n\tContainer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0epod_sandbox_id\x18\x02 \x01(\t\x12,\n\x08metadata\x18\x03 \x01(\x0b\x32\x1a.runtime.ContainerMetadata\x12!\n\x05image\x18\x04 \x01(\x0b\x32\x12.runtime.ImageSpec\x12\x11\n\timage_ref\x18\x05 \x01(\t\x12&\n\x05state\x18\x06 \x01(\x0e\x32\x17.runtime.ContainerState\x12\x12\n\ncreated_at\x18\x07 \x01(\x03\x12.\n\x06labels\x18\x08 \x03(\x0b\x32\x1e.runtime.Container.LabelsEntry\x12\x38\n\x0b\x61nnotations\x18\t \x03(\x0b\x32#.runtime.Container.AnnotationsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\x16ListContainersResponse\x12&\n\ncontainers\x18\x01 \x03(\x0b\x32\x12.runtime.Container\".\n\x16\x43ontainerStatusRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\"\x93\x04\n\x0f\x43ontainerStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n\x08metadata\x18\x02 \x01(\x0b\x32\x1a.runtime.ContainerMetadata\x12&\n\x05state\x18\x03 \x01(\x0e\x32\x17.runtime.ContainerState\x12\x12\n\ncreated_at\x18\x04 \x01(\x03\x12\x12\n\nstarted_at\x18\x05 \x01(\x03\x12\x13\n\x0b\x66inished_at\x18\x06 \x01(\x03\x12\x11\n\texit_code\x18\x07 \x01(\x05\x12!\n\x05image\x18\x08 \x01(\x0b\x32\x12.runtime.ImageSpec\x12\x11\n\timage_ref\x18\t \x01(\t\x12\x0e\n\x06reason\x18\n \x01(\t\x12\x0f\n\x07message\x18\x0b \x01(\t\x12\x34\n\x06labels\x18\x0c \x03(\x0b\x32$.runtime.ContainerStatus.LabelsEntry\x12>\n\x0b\x61nnotations\x18\r \x03(\x0b\x32).runtime.ContainerStatus.AnnotationsEntry\x12\x1e\n\x06mounts\x18\x0e \x03(\x0b\x32\x0e.runtime.Mount\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"C\n\x17\x43ontainerStatusResponse\x12(\n\x06status\x18\x01 \x01(\x0b\x32\x18.runtime.ContainerStatus\"E\n\x0f\x45xecSyncRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x03(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\"E\n\x10\x45xecSyncResponse\x12\x0e\n\x06stdout\x18\x01 \x01(\x0c\x12\x0e\n\x06stderr\x18\x02 \x01(\x0c\x12\x11\n\texit_code\x18\x03 \x01(\x05\"L\n\x0b\x45xecRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x03(\t\x12\x0b\n\x03tty\x18\x03 \x01(\x08\x12\r\n\x05stdin\x18\x04 \x01(\x08\"\x1b\n\x0c\x45xecResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\"A\n\rAttachRequest\x12\x14\n\x0c\x63ontainer_id\x18\x01 \x01(\t\x12\r\n\x05stdin\x18\x02 \x01(\x08\x12\x0b\n\x03tty\x18\x03 \x01(\x08\"\x1d\n\x0e\x41ttachResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\":\n\x12PortForwardRequest\x12\x16\n\x0epod_sandbox_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x03(\x05\"\"\n\x13PortForwardResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\"0\n\x0bImageFilter\x12!\n\x05image\x18\x01 \x01(\x0b\x32\x12.runtime.ImageSpec\"9\n\x11ListImagesRequest\x12$\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x14.runtime.ImageFilter\"~\n\x05Image\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\trepo_tags\x18\x02 \x03(\t\x12\x14\n\x0crepo_digests\x18\x03 \x03(\t\x12\x0c\n\x04size\x18\x04 \x01(\x04\x12 \n\x03uid\x18\x05 \x01(\x0b\x32\x13.runtime.Int64Value\x12\x10\n\x08username\x18\x06 \x01(\t\"4\n\x12ListImagesResponse\x12\x1e\n\x06images\x18\x01 \x03(\x0b\x32\x0e.runtime.Image\"7\n\x12ImageStatusRequest\x12!\n\x05image\x18\x01 \x01(\x0b\x32\x12.runtime.ImageSpec\"4\n\x13ImageStatusResponse\x12\x1d\n\x05image\x18\x01 \x01(\x0b\x32\x0e.runtime.Image\"\x86\x01\n\nAuthConfig\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04\x61uth\x18\x03 \x01(\t\x12\x16\n\x0eserver_address\x18\x04 \x01(\t\x12\x16\n\x0eidentity_token\x18\x05 \x01(\t\x12\x16\n\x0eregistry_token\x18\x06 \x01(\t\"\x8b\x01\n\x10PullImageRequest\x12!\n\x05image\x18\x01 \x01(\x0b\x32\x12.runtime.ImageSpec\x12!\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x13.runtime.AuthConfig\x12\x31\n\x0esandbox_config\x18\x03 \x01(\x0b\x32\x19.runtime.PodSandboxConfig\"&\n\x11PullImageResponse\x12\x11\n\timage_ref\x18\x01 \x01(\t\"7\n\x12RemoveImageRequest\x12!\n\x05image\x18\x01 \x01(\x0b\x32\x12.runtime.ImageSpec\"\x15\n\x13RemoveImageResponse\"!\n\rNetworkConfig\x12\x10\n\x08pod_cidr\x18\x01 \x01(\t\"?\n\rRuntimeConfig\x12.\n\x0enetwork_config\x18\x01 \x01(\x0b\x32\x16.runtime.NetworkConfig\"L\n\x1aUpdateRuntimeConfigRequest\x12.\n\x0eruntime_config\x18\x01 \x01(\x0b\x32\x16.runtime.RuntimeConfig\"\x1d\n\x1bUpdateRuntimeConfigResponse\"Q\n\x10RuntimeCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\x08\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\">\n\rRuntimeStatus\x12-\n\nconditions\x18\x01 \x03(\x0b\x32\x19.runtime.RuntimeCondition\"\x0f\n\rStatusRequest\"8\n\x0eStatusResponse\x12&\n\x06status\x18\x01 \x01(\x0b\x32\x16.runtime.RuntimeStatus*\x1c\n\x08Protocol\x12\x07\n\x03TCP\x10\x00\x12\x07\n\x03UDP\x10\x01*:\n\x0fPodSandboxState\x12\x11\n\rSANDBOX_READY\x10\x00\x12\x14\n\x10SANDBOX_NOTREADY\x10\x01*k\n\x0e\x43ontainerState\x12\x15\n\x11\x43ONTAINER_CREATED\x10\x00\x12\x15\n\x11\x43ONTAINER_RUNNING\x10\x01\x12\x14\n\x10\x43ONTAINER_EXITED\x10\x02\x12\x15\n\x11\x43ONTAINER_UNKNOWN\x10\x03\x32\xaa\x0b\n\x0eRuntimeService\x12>\n\x07Version\x12\x17.runtime.VersionRequest\x1a\x18.runtime.VersionResponse\"\x00\x12P\n\rRunPodSandbox\x12\x1d.runtime.RunPodSandboxRequest\x1a\x1e.runtime.RunPodSandboxResponse\"\x00\x12S\n\x0eStopPodSandbox\x12\x1e.runtime.StopPodSandboxRequest\x1a\x1f.runtime.StopPodSandboxResponse\"\x00\x12Y\n\x10RemovePodSandbox\x12 .runtime.RemovePodSandboxRequest\x1a!.runtime.RemovePodSandboxResponse\"\x00\x12Y\n\x10PodSandboxStatus\x12 .runtime.PodSandboxStatusRequest\x1a!.runtime.PodSandboxStatusResponse\"\x00\x12S\n\x0eListPodSandbox\x12\x1e.runtime.ListPodSandboxRequest\x1a\x1f.runtime.ListPodSandboxResponse\"\x00\x12V\n\x0f\x43reateContainer\x12\x1f.runtime.CreateContainerRequest\x1a .runtime.CreateContainerResponse\"\x00\x12S\n\x0eStartContainer\x12\x1e.runtime.StartContainerRequest\x1a\x1f.runtime.StartContainerResponse\"\x00\x12P\n\rStopContainer\x12\x1d.runtime.StopContainerRequest\x1a\x1e.runtime.StopContainerResponse\"\x00\x12V\n\x0fRemoveContainer\x12\x1f.runtime.RemoveContainerRequest\x1a .runtime.RemoveContainerResponse\"\x00\x12S\n\x0eListContainers\x12\x1e.runtime.ListContainersRequest\x1a\x1f.runtime.ListContainersResponse\"\x00\x12V\n\x0f\x43ontainerStatus\x12\x1f.runtime.ContainerStatusRequest\x1a .runtime.ContainerStatusResponse\"\x00\x12\x41\n\x08\x45xecSync\x12\x18.runtime.ExecSyncRequest\x1a\x19.runtime.ExecSyncResponse\"\x00\x12\x35\n\x04\x45xec\x12\x14.runtime.ExecRequest\x1a\x15.runtime.ExecResponse\"\x00\x12;\n\x06\x41ttach\x12\x16.runtime.AttachRequest\x1a\x17.runtime.AttachResponse\"\x00\x12J\n\x0bPortForward\x12\x1b.runtime.PortForwardRequest\x1a\x1c.runtime.PortForwardResponse\"\x00\x12\x62\n\x13UpdateRuntimeConfig\x12#.runtime.UpdateRuntimeConfigRequest\x1a$.runtime.UpdateRuntimeConfigResponse\"\x00\x12;\n\x06Status\x12\x16.runtime.StatusRequest\x1a\x17.runtime.StatusResponse\"\x00\x32\xb5\x02\n\x0cImageService\x12G\n\nListImages\x12\x1a.runtime.ListImagesRequest\x1a\x1b.runtime.ListImagesResponse\"\x00\x12J\n\x0bImageStatus\x12\x1b.runtime.ImageStatusRequest\x1a\x1c.runtime.ImageStatusResponse\"\x00\x12\x44\n\tPullImage\x12\x19.runtime.PullImageRequest\x1a\x1a.runtime.PullImageResponse\"\x00\x12J\n\x0bRemoveImage\x12\x1b.runtime.RemoveImageRequest\x1a\x1c.runtime.RemoveImageResponse\"\x00\x42\x1c\xd8\xe1\x1e\x00\x80\xe2\x1e\x01\xc8\xe1\x1e\x01\xc8\xe2\x1e\x01\xe0\xe2\x1e\x01\xd0\xe2\x1e\x01\x90\xe3\x1e\x00\x62\x06proto3')
  ,
  dependencies=[github_dot_com_dot_gogo_dot_protobuf_dot_gogoproto_dot_gogo__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='runtime.Protocol',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TCP', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UDP', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8379,
  serialized_end=8407,
)
_sym_db.RegisterEnumDescriptor(_PROTOCOL)

Protocol = enum_type_wrapper.EnumTypeWrapper(_PROTOCOL)
_PODSANDBOXSTATE = _descriptor.EnumDescriptor(
  name='PodSandboxState',
  full_name='runtime.PodSandboxState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SANDBOX_READY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SANDBOX_NOTREADY', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8409,
  serialized_end=8467,
)
_sym_db.RegisterEnumDescriptor(_PODSANDBOXSTATE)

PodSandboxState = enum_type_wrapper.EnumTypeWrapper(_PODSANDBOXSTATE)
_CONTAINERSTATE = _descriptor.EnumDescriptor(
  name='ContainerState',
  full_name='runtime.ContainerState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_CREATED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_RUNNING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_EXITED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_UNKNOWN', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=8469,
  serialized_end=8576,
)
_sym_db.RegisterEnumDescriptor(_CONTAINERSTATE)

ContainerState = enum_type_wrapper.EnumTypeWrapper(_CONTAINERSTATE)
TCP = 0
UDP = 1
SANDBOX_READY = 0
SANDBOX_NOTREADY = 1
CONTAINER_CREATED = 0
CONTAINER_RUNNING = 1
CONTAINER_EXITED = 2
CONTAINER_UNKNOWN = 3



_VERSIONREQUEST = _descriptor.Descriptor(
  name='VersionRequest',
  full_name='runtime.VersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='runtime.VersionRequest.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=102,
)


_VERSIONRESPONSE = _descriptor.Descriptor(
  name='VersionResponse',
  full_name='runtime.VersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='runtime.VersionResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runtime_name', full_name='runtime.VersionResponse.runtime_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runtime_version', full_name='runtime.VersionResponse.runtime_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runtime_api_version', full_name='runtime.VersionResponse.runtime_api_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=214,
)


_DNSCONFIG = _descriptor.Descriptor(
  name='DNSConfig',
  full_name='runtime.DNSConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='servers', full_name='runtime.DNSConfig.servers', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='searches', full_name='runtime.DNSConfig.searches', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='options', full_name='runtime.DNSConfig.options', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=216,
  serialized_end=279,
)


_PORTMAPPING = _descriptor.Descriptor(
  name='PortMapping',
  full_name='runtime.PortMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='runtime.PortMapping.protocol', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='container_port', full_name='runtime.PortMapping.container_port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_port', full_name='runtime.PortMapping.host_port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_ip', full_name='runtime.PortMapping.host_ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=391,
)


_MOUNT = _descriptor.Descriptor(
  name='Mount',
  full_name='runtime.Mount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_path', full_name='runtime.Mount.container_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_path', full_name='runtime.Mount.host_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='readonly', full_name='runtime.Mount.readonly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selinux_relabel', full_name='runtime.Mount.selinux_relabel', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=486,
)


_NAMESPACEOPTION = _descriptor.Descriptor(
  name='NamespaceOption',
  full_name='runtime.NamespaceOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_network', full_name='runtime.NamespaceOption.host_network', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_pid', full_name='runtime.NamespaceOption.host_pid', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_ipc', full_name='runtime.NamespaceOption.host_ipc', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=563,
)


_INT64VALUE = _descriptor.Descriptor(
  name='Int64Value',
  full_name='runtime.Int64Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.Int64Value.value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=565,
  serialized_end=592,
)


_LINUXSANDBOXSECURITYCONTEXT = _descriptor.Descriptor(
  name='LinuxSandboxSecurityContext',
  full_name='runtime.LinuxSandboxSecurityContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace_options', full_name='runtime.LinuxSandboxSecurityContext.namespace_options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selinux_options', full_name='runtime.LinuxSandboxSecurityContext.selinux_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='run_as_user', full_name='runtime.LinuxSandboxSecurityContext.run_as_user', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='readonly_rootfs', full_name='runtime.LinuxSandboxSecurityContext.readonly_rootfs', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='supplemental_groups', full_name='runtime.LinuxSandboxSecurityContext.supplemental_groups', index=4,
      number=5, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='privileged', full_name='runtime.LinuxSandboxSecurityContext.privileged', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=842,
)


_LINUXPODSANDBOXCONFIG = _descriptor.Descriptor(
  name='LinuxPodSandboxConfig',
  full_name='runtime.LinuxPodSandboxConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cgroup_parent', full_name='runtime.LinuxPodSandboxConfig.cgroup_parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='security_context', full_name='runtime.LinuxPodSandboxConfig.security_context', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=844,
  serialized_end=954,
)


_PODSANDBOXMETADATA = _descriptor.Descriptor(
  name='PodSandboxMetadata',
  full_name='runtime.PodSandboxMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='runtime.PodSandboxMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uid', full_name='runtime.PodSandboxMetadata.uid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='runtime.PodSandboxMetadata.namespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attempt', full_name='runtime.PodSandboxMetadata.attempt', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=956,
  serialized_end=1039,
)


_PODSANDBOXCONFIG_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='runtime.PodSandboxConfig.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.PodSandboxConfig.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.PodSandboxConfig.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1447,
)

_PODSANDBOXCONFIG_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='runtime.PodSandboxConfig.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.PodSandboxConfig.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.PodSandboxConfig.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1449,
  serialized_end=1499,
)

_PODSANDBOXCONFIG = _descriptor.Descriptor(
  name='PodSandboxConfig',
  full_name='runtime.PodSandboxConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='runtime.PodSandboxConfig.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='runtime.PodSandboxConfig.hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='log_directory', full_name='runtime.PodSandboxConfig.log_directory', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dns_config', full_name='runtime.PodSandboxConfig.dns_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port_mappings', full_name='runtime.PodSandboxConfig.port_mappings', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='labels', full_name='runtime.PodSandboxConfig.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='runtime.PodSandboxConfig.annotations', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='linux', full_name='runtime.PodSandboxConfig.linux', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PODSANDBOXCONFIG_LABELSENTRY, _PODSANDBOXCONFIG_ANNOTATIONSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1042,
  serialized_end=1499,
)


_RUNPODSANDBOXREQUEST = _descriptor.Descriptor(
  name='RunPodSandboxRequest',
  full_name='runtime.RunPodSandboxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='runtime.RunPodSandboxRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1566,
)


_RUNPODSANDBOXRESPONSE = _descriptor.Descriptor(
  name='RunPodSandboxResponse',
  full_name='runtime.RunPodSandboxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pod_sandbox_id', full_name='runtime.RunPodSandboxResponse.pod_sandbox_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1568,
  serialized_end=1615,
)


_STOPPODSANDBOXREQUEST = _descriptor.Descriptor(
  name='StopPodSandboxRequest',
  full_name='runtime.StopPodSandboxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pod_sandbox_id', full_name='runtime.StopPodSandboxRequest.pod_sandbox_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1617,
  serialized_end=1664,
)


_STOPPODSANDBOXRESPONSE = _descriptor.Descriptor(
  name='StopPodSandboxResponse',
  full_name='runtime.StopPodSandboxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1666,
  serialized_end=1690,
)


_REMOVEPODSANDBOXREQUEST = _descriptor.Descriptor(
  name='RemovePodSandboxRequest',
  full_name='runtime.RemovePodSandboxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pod_sandbox_id', full_name='runtime.RemovePodSandboxRequest.pod_sandbox_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1741,
)


_REMOVEPODSANDBOXRESPONSE = _descriptor.Descriptor(
  name='RemovePodSandboxResponse',
  full_name='runtime.RemovePodSandboxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1743,
  serialized_end=1769,
)


_PODSANDBOXSTATUSREQUEST = _descriptor.Descriptor(
  name='PodSandboxStatusRequest',
  full_name='runtime.PodSandboxStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pod_sandbox_id', full_name='runtime.PodSandboxStatusRequest.pod_sandbox_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1771,
  serialized_end=1820,
)


_PODSANDBOXNETWORKSTATUS = _descriptor.Descriptor(
  name='PodSandboxNetworkStatus',
  full_name='runtime.PodSandboxNetworkStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='runtime.PodSandboxNetworkStatus.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=1859,
)


_NAMESPACE = _descriptor.Descriptor(
  name='Namespace',
  full_name='runtime.Namespace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='network', full_name='runtime.Namespace.network', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='options', full_name='runtime.Namespace.options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1861,
  serialized_end=1932,
)


_LINUXPODSANDBOXSTATUS = _descriptor.Descriptor(
  name='LinuxPodSandboxStatus',
  full_name='runtime.LinuxPodSandboxStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='runtime.LinuxPodSandboxStatus.namespaces', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1934,
  serialized_end=1997,
)


_PODSANDBOXSTATUS_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='runtime.PodSandboxStatus.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.PodSandboxStatus.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.PodSandboxStatus.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1447,
)

_PODSANDBOXSTATUS_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='runtime.PodSandboxStatus.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.PodSandboxStatus.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.PodSandboxStatus.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1449,
  serialized_end=1499,
)

_PODSANDBOXSTATUS = _descriptor.Descriptor(
  name='PodSandboxStatus',
  full_name='runtime.PodSandboxStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='runtime.PodSandboxStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='runtime.PodSandboxStatus.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='runtime.PodSandboxStatus.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='runtime.PodSandboxStatus.created_at', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='network', full_name='runtime.PodSandboxStatus.network', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='linux', full_name='runtime.PodSandboxStatus.linux', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='labels', full_name='runtime.PodSandboxStatus.labels', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='runtime.PodSandboxStatus.annotations', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PODSANDBOXSTATUS_LABELSENTRY, _PODSANDBOXSTATUS_ANNOTATIONSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2000,
  serialized_end=2455,
)


_PODSANDBOXSTATUSRESPONSE = _descriptor.Descriptor(
  name='PodSandboxStatusResponse',
  full_name='runtime.PodSandboxStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='runtime.PodSandboxStatusResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2457,
  serialized_end=2526,
)


_PODSANDBOXSTATEVALUE = _descriptor.Descriptor(
  name='PodSandboxStateValue',
  full_name='runtime.PodSandboxStateValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='runtime.PodSandboxStateValue.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2528,
  serialized_end=2591,
)


_PODSANDBOXFILTER_LABELSELECTORENTRY = _descriptor.Descriptor(
  name='LabelSelectorEntry',
  full_name='runtime.PodSandboxFilter.LabelSelectorEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.PodSandboxFilter.LabelSelectorEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.PodSandboxFilter.LabelSelectorEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2742,
  serialized_end=2794,
)

_PODSANDBOXFILTER = _descriptor.Descriptor(
  name='PodSandboxFilter',
  full_name='runtime.PodSandboxFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='runtime.PodSandboxFilter.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='runtime.PodSandboxFilter.state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='label_selector', full_name='runtime.PodSandboxFilter.label_selector', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PODSANDBOXFILTER_LABELSELECTORENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2594,
  serialized_end=2794,
)


_LISTPODSANDBOXREQUEST = _descriptor.Descriptor(
  name='ListPodSandboxRequest',
  full_name='runtime.ListPodSandboxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='runtime.ListPodSandboxRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2796,
  serialized_end=2862,
)


_PODSANDBOX_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='runtime.PodSandbox.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.PodSandbox.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.PodSandbox.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1447,
)

_PODSANDBOX_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='runtime.PodSandbox.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.PodSandbox.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.PodSandbox.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1449,
  serialized_end=1499,
)

_PODSANDBOX = _descriptor.Descriptor(
  name='PodSandbox',
  full_name='runtime.PodSandbox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='runtime.PodSandbox.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='runtime.PodSandbox.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='runtime.PodSandbox.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='runtime.PodSandbox.created_at', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='labels', full_name='runtime.PodSandbox.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='runtime.PodSandbox.annotations', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PODSANDBOX_LABELSENTRY, _PODSANDBOX_ANNOTATIONSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2865,
  serialized_end=3204,
)


_LISTPODSANDBOXRESPONSE = _descriptor.Descriptor(
  name='ListPodSandboxResponse',
  full_name='runtime.ListPodSandboxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='runtime.ListPodSandboxResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3206,
  serialized_end=3266,
)


_IMAGESPEC = _descriptor.Descriptor(
  name='ImageSpec',
  full_name='runtime.ImageSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='runtime.ImageSpec.image', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3268,
  serialized_end=3294,
)


_KEYVALUE = _descriptor.Descriptor(
  name='KeyValue',
  full_name='runtime.KeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.KeyValue.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.KeyValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3296,
  serialized_end=3334,
)


_LINUXCONTAINERRESOURCES = _descriptor.Descriptor(
  name='LinuxContainerResources',
  full_name='runtime.LinuxContainerResources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu_period', full_name='runtime.LinuxContainerResources.cpu_period', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu_quota', full_name='runtime.LinuxContainerResources.cpu_quota', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu_shares', full_name='runtime.LinuxContainerResources.cpu_shares', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memory_limit_in_bytes', full_name='runtime.LinuxContainerResources.memory_limit_in_bytes', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='oom_score_adj', full_name='runtime.LinuxContainerResources.oom_score_adj', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3337,
  serialized_end=3475,
)


_SELINUXOPTION = _descriptor.Descriptor(
  name='SELinuxOption',
  full_name='runtime.SELinuxOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='runtime.SELinuxOption.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='runtime.SELinuxOption.role', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='runtime.SELinuxOption.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='runtime.SELinuxOption.level', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3477,
  serialized_end=3549,
)


_CAPABILITY = _descriptor.Descriptor(
  name='Capability',
  full_name='runtime.Capability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='add_capabilities', full_name='runtime.Capability.add_capabilities', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='drop_capabilities', full_name='runtime.Capability.drop_capabilities', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3551,
  serialized_end=3616,
)


_LINUXCONTAINERSECURITYCONTEXT = _descriptor.Descriptor(
  name='LinuxContainerSecurityContext',
  full_name='runtime.LinuxContainerSecurityContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='runtime.LinuxContainerSecurityContext.capabilities', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='privileged', full_name='runtime.LinuxContainerSecurityContext.privileged', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='namespace_options', full_name='runtime.LinuxContainerSecurityContext.namespace_options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='selinux_options', full_name='runtime.LinuxContainerSecurityContext.selinux_options', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='run_as_user', full_name='runtime.LinuxContainerSecurityContext.run_as_user', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='run_as_username', full_name='runtime.LinuxContainerSecurityContext.run_as_username', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='readonly_rootfs', full_name='runtime.LinuxContainerSecurityContext.readonly_rootfs', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='supplemental_groups', full_name='runtime.LinuxContainerSecurityContext.supplemental_groups', index=7,
      number=8, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3619,
  serialized_end=3936,
)


_LINUXCONTAINERCONFIG = _descriptor.Descriptor(
  name='LinuxContainerConfig',
  full_name='runtime.LinuxContainerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resources', full_name='runtime.LinuxContainerConfig.resources', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='security_context', full_name='runtime.LinuxContainerConfig.security_context', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3939,
  serialized_end=4080,
)


_CONTAINERMETADATA = _descriptor.Descriptor(
  name='ContainerMetadata',
  full_name='runtime.ContainerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='runtime.ContainerMetadata.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attempt', full_name='runtime.ContainerMetadata.attempt', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4082,
  serialized_end=4132,
)


_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='runtime.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_path', full_name='runtime.Device.container_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_path', full_name='runtime.Device.host_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permissions', full_name='runtime.Device.permissions', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4134,
  serialized_end=4206,
)


_CONTAINERCONFIG_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='runtime.ContainerConfig.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.ContainerConfig.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.ContainerConfig.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1447,
)

_CONTAINERCONFIG_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='runtime.ContainerConfig.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.ContainerConfig.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.ContainerConfig.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1449,
  serialized_end=1499,
)

_CONTAINERCONFIG = _descriptor.Descriptor(
  name='ContainerConfig',
  full_name='runtime.ContainerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='runtime.ContainerConfig.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image', full_name='runtime.ContainerConfig.image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command', full_name='runtime.ContainerConfig.command', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='args', full_name='runtime.ContainerConfig.args', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='working_dir', full_name='runtime.ContainerConfig.working_dir', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='envs', full_name='runtime.ContainerConfig.envs', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mounts', full_name='runtime.ContainerConfig.mounts', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='devices', full_name='runtime.ContainerConfig.devices', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='labels', full_name='runtime.ContainerConfig.labels', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='runtime.ContainerConfig.annotations', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='log_path', full_name='runtime.ContainerConfig.log_path', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stdin', full_name='runtime.ContainerConfig.stdin', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stdin_once', full_name='runtime.ContainerConfig.stdin_once', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tty', full_name='runtime.ContainerConfig.tty', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='linux', full_name='runtime.ContainerConfig.linux', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CONTAINERCONFIG_LABELSENTRY, _CONTAINERCONFIG_ANNOTATIONSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4209,
  serialized_end=4787,
)


_CREATECONTAINERREQUEST = _descriptor.Descriptor(
  name='CreateContainerRequest',
  full_name='runtime.CreateContainerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pod_sandbox_id', full_name='runtime.CreateContainerRequest.pod_sandbox_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='config', full_name='runtime.CreateContainerRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sandbox_config', full_name='runtime.CreateContainerRequest.sandbox_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4790,
  serialized_end=4931,
)


_CREATECONTAINERRESPONSE = _descriptor.Descriptor(
  name='CreateContainerResponse',
  full_name='runtime.CreateContainerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='runtime.CreateContainerResponse.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4933,
  serialized_end=4980,
)


_STARTCONTAINERREQUEST = _descriptor.Descriptor(
  name='StartContainerRequest',
  full_name='runtime.StartContainerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='runtime.StartContainerRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4982,
  serialized_end=5027,
)


_STARTCONTAINERRESPONSE = _descriptor.Descriptor(
  name='StartContainerResponse',
  full_name='runtime.StartContainerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5029,
  serialized_end=5053,
)


_STOPCONTAINERREQUEST = _descriptor.Descriptor(
  name='StopContainerRequest',
  full_name='runtime.StopContainerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='runtime.StopContainerRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='runtime.StopContainerRequest.timeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5055,
  serialized_end=5116,
)


_STOPCONTAINERRESPONSE = _descriptor.Descriptor(
  name='StopContainerResponse',
  full_name='runtime.StopContainerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5118,
  serialized_end=5141,
)


_REMOVECONTAINERREQUEST = _descriptor.Descriptor(
  name='RemoveContainerRequest',
  full_name='runtime.RemoveContainerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='runtime.RemoveContainerRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5143,
  serialized_end=5189,
)


_REMOVECONTAINERRESPONSE = _descriptor.Descriptor(
  name='RemoveContainerResponse',
  full_name='runtime.RemoveContainerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5191,
  serialized_end=5216,
)


_CONTAINERSTATEVALUE = _descriptor.Descriptor(
  name='ContainerStateValue',
  full_name='runtime.ContainerStateValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='runtime.ContainerStateValue.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5218,
  serialized_end=5279,
)


_CONTAINERFILTER_LABELSELECTORENTRY = _descriptor.Descriptor(
  name='LabelSelectorEntry',
  full_name='runtime.ContainerFilter.LabelSelectorEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.ContainerFilter.LabelSelectorEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.ContainerFilter.LabelSelectorEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2742,
  serialized_end=2794,
)

_CONTAINERFILTER = _descriptor.Descriptor(
  name='ContainerFilter',
  full_name='runtime.ContainerFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='runtime.ContainerFilter.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='runtime.ContainerFilter.state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pod_sandbox_id', full_name='runtime.ContainerFilter.pod_sandbox_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='label_selector', full_name='runtime.ContainerFilter.label_selector', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CONTAINERFILTER_LABELSELECTORENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5282,
  serialized_end=5503,
)


_LISTCONTAINERSREQUEST = _descriptor.Descriptor(
  name='ListContainersRequest',
  full_name='runtime.ListContainersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='runtime.ListContainersRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5505,
  serialized_end=5570,
)


_CONTAINER_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='runtime.Container.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.Container.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.Container.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1447,
)

_CONTAINER_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='runtime.Container.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.Container.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.Container.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1449,
  serialized_end=1499,
)

_CONTAINER = _descriptor.Descriptor(
  name='Container',
  full_name='runtime.Container',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='runtime.Container.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pod_sandbox_id', full_name='runtime.Container.pod_sandbox_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='runtime.Container.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image', full_name='runtime.Container.image', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image_ref', full_name='runtime.Container.image_ref', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='runtime.Container.state', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='runtime.Container.created_at', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='labels', full_name='runtime.Container.labels', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='runtime.Container.annotations', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CONTAINER_LABELSENTRY, _CONTAINER_ANNOTATIONSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5573,
  serialized_end=5985,
)


_LISTCONTAINERSRESPONSE = _descriptor.Descriptor(
  name='ListContainersResponse',
  full_name='runtime.ListContainersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='containers', full_name='runtime.ListContainersResponse.containers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5987,
  serialized_end=6051,
)


_CONTAINERSTATUSREQUEST = _descriptor.Descriptor(
  name='ContainerStatusRequest',
  full_name='runtime.ContainerStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='runtime.ContainerStatusRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6053,
  serialized_end=6099,
)


_CONTAINERSTATUS_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='runtime.ContainerStatus.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.ContainerStatus.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.ContainerStatus.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1447,
)

_CONTAINERSTATUS_ANNOTATIONSENTRY = _descriptor.Descriptor(
  name='AnnotationsEntry',
  full_name='runtime.ContainerStatus.AnnotationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='runtime.ContainerStatus.AnnotationsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='runtime.ContainerStatus.AnnotationsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1449,
  serialized_end=1499,
)

_CONTAINERSTATUS = _descriptor.Descriptor(
  name='ContainerStatus',
  full_name='runtime.ContainerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='runtime.ContainerStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='runtime.ContainerStatus.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='runtime.ContainerStatus.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='runtime.ContainerStatus.created_at', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='runtime.ContainerStatus.started_at', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='finished_at', full_name='runtime.ContainerStatus.finished_at', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='runtime.ContainerStatus.exit_code', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image', full_name='runtime.ContainerStatus.image', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image_ref', full_name='runtime.ContainerStatus.image_ref', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='runtime.ContainerStatus.reason', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='runtime.ContainerStatus.message', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='labels', full_name='runtime.ContainerStatus.labels', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='runtime.ContainerStatus.annotations', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mounts', full_name='runtime.ContainerStatus.mounts', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CONTAINERSTATUS_LABELSENTRY, _CONTAINERSTATUS_ANNOTATIONSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6102,
  serialized_end=6633,
)


_CONTAINERSTATUSRESPONSE = _descriptor.Descriptor(
  name='ContainerStatusResponse',
  full_name='runtime.ContainerStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='runtime.ContainerStatusResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6635,
  serialized_end=6702,
)


_EXECSYNCREQUEST = _descriptor.Descriptor(
  name='ExecSyncRequest',
  full_name='runtime.ExecSyncRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='runtime.ExecSyncRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='runtime.ExecSyncRequest.cmd', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='runtime.ExecSyncRequest.timeout', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6704,
  serialized_end=6773,
)


_EXECSYNCRESPONSE = _descriptor.Descriptor(
  name='ExecSyncResponse',
  full_name='runtime.ExecSyncResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stdout', full_name='runtime.ExecSyncResponse.stdout', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stderr', full_name='runtime.ExecSyncResponse.stderr', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='runtime.ExecSyncResponse.exit_code', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6775,
  serialized_end=6844,
)


_EXECREQUEST = _descriptor.Descriptor(
  name='ExecRequest',
  full_name='runtime.ExecRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='runtime.ExecRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='runtime.ExecRequest.cmd', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tty', full_name='runtime.ExecRequest.tty', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stdin', full_name='runtime.ExecRequest.stdin', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6846,
  serialized_end=6922,
)


_EXECRESPONSE = _descriptor.Descriptor(
  name='ExecResponse',
  full_name='runtime.ExecResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='runtime.ExecResponse.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6924,
  serialized_end=6951,
)


_ATTACHREQUEST = _descriptor.Descriptor(
  name='AttachRequest',
  full_name='runtime.AttachRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_id', full_name='runtime.AttachRequest.container_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stdin', full_name='runtime.AttachRequest.stdin', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tty', full_name='runtime.AttachRequest.tty', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6953,
  serialized_end=7018,
)


_ATTACHRESPONSE = _descriptor.Descriptor(
  name='AttachResponse',
  full_name='runtime.AttachResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='runtime.AttachResponse.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7020,
  serialized_end=7049,
)


_PORTFORWARDREQUEST = _descriptor.Descriptor(
  name='PortForwardRequest',
  full_name='runtime.PortForwardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pod_sandbox_id', full_name='runtime.PortForwardRequest.pod_sandbox_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='runtime.PortForwardRequest.port', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7051,
  serialized_end=7109,
)


_PORTFORWARDRESPONSE = _descriptor.Descriptor(
  name='PortForwardResponse',
  full_name='runtime.PortForwardResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='runtime.PortForwardResponse.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7111,
  serialized_end=7145,
)


_IMAGEFILTER = _descriptor.Descriptor(
  name='ImageFilter',
  full_name='runtime.ImageFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='runtime.ImageFilter.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7147,
  serialized_end=7195,
)


_LISTIMAGESREQUEST = _descriptor.Descriptor(
  name='ListImagesRequest',
  full_name='runtime.ListImagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='runtime.ListImagesRequest.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7197,
  serialized_end=7254,
)


_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='runtime.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='runtime.Image.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='repo_tags', full_name='runtime.Image.repo_tags', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='repo_digests', full_name='runtime.Image.repo_digests', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='size', full_name='runtime.Image.size', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uid', full_name='runtime.Image.uid', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='username', full_name='runtime.Image.username', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7256,
  serialized_end=7382,
)


_LISTIMAGESRESPONSE = _descriptor.Descriptor(
  name='ListImagesResponse',
  full_name='runtime.ListImagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='images', full_name='runtime.ListImagesResponse.images', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7384,
  serialized_end=7436,
)


_IMAGESTATUSREQUEST = _descriptor.Descriptor(
  name='ImageStatusRequest',
  full_name='runtime.ImageStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='runtime.ImageStatusRequest.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7438,
  serialized_end=7493,
)


_IMAGESTATUSRESPONSE = _descriptor.Descriptor(
  name='ImageStatusResponse',
  full_name='runtime.ImageStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='runtime.ImageStatusResponse.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7495,
  serialized_end=7547,
)


_AUTHCONFIG = _descriptor.Descriptor(
  name='AuthConfig',
  full_name='runtime.AuthConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='runtime.AuthConfig.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='password', full_name='runtime.AuthConfig.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='auth', full_name='runtime.AuthConfig.auth', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='server_address', full_name='runtime.AuthConfig.server_address', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='identity_token', full_name='runtime.AuthConfig.identity_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='registry_token', full_name='runtime.AuthConfig.registry_token', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7550,
  serialized_end=7684,
)


_PULLIMAGEREQUEST = _descriptor.Descriptor(
  name='PullImageRequest',
  full_name='runtime.PullImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='runtime.PullImageRequest.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='auth', full_name='runtime.PullImageRequest.auth', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sandbox_config', full_name='runtime.PullImageRequest.sandbox_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7687,
  serialized_end=7826,
)


_PULLIMAGERESPONSE = _descriptor.Descriptor(
  name='PullImageResponse',
  full_name='runtime.PullImageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_ref', full_name='runtime.PullImageResponse.image_ref', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7828,
  serialized_end=7866,
)


_REMOVEIMAGEREQUEST = _descriptor.Descriptor(
  name='RemoveImageRequest',
  full_name='runtime.RemoveImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='runtime.RemoveImageRequest.image', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7868,
  serialized_end=7923,
)


_REMOVEIMAGERESPONSE = _descriptor.Descriptor(
  name='RemoveImageResponse',
  full_name='runtime.RemoveImageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7925,
  serialized_end=7946,
)


_NETWORKCONFIG = _descriptor.Descriptor(
  name='NetworkConfig',
  full_name='runtime.NetworkConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pod_cidr', full_name='runtime.NetworkConfig.pod_cidr', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7948,
  serialized_end=7981,
)


_RUNTIMECONFIG = _descriptor.Descriptor(
  name='RuntimeConfig',
  full_name='runtime.RuntimeConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_config', full_name='runtime.RuntimeConfig.network_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7983,
  serialized_end=8046,
)


_UPDATERUNTIMECONFIGREQUEST = _descriptor.Descriptor(
  name='UpdateRuntimeConfigRequest',
  full_name='runtime.UpdateRuntimeConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='runtime_config', full_name='runtime.UpdateRuntimeConfigRequest.runtime_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8048,
  serialized_end=8124,
)


_UPDATERUNTIMECONFIGRESPONSE = _descriptor.Descriptor(
  name='UpdateRuntimeConfigResponse',
  full_name='runtime.UpdateRuntimeConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8126,
  serialized_end=8155,
)


_RUNTIMECONDITION = _descriptor.Descriptor(
  name='RuntimeCondition',
  full_name='runtime.RuntimeCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='runtime.RuntimeCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='runtime.RuntimeCondition.status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='runtime.RuntimeCondition.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='runtime.RuntimeCondition.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8157,
  serialized_end=8238,
)


_RUNTIMESTATUS = _descriptor.Descriptor(
  name='RuntimeStatus',
  full_name='runtime.RuntimeStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conditions', full_name='runtime.RuntimeStatus.conditions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8240,
  serialized_end=8302,
)


_STATUSREQUEST = _descriptor.Descriptor(
  name='StatusRequest',
  full_name='runtime.StatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8304,
  serialized_end=8319,
)


_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='runtime.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='runtime.StatusResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8321,
  serialized_end=8377,
)

_PORTMAPPING.fields_by_name['protocol'].enum_type = _PROTOCOL
_LINUXSANDBOXSECURITYCONTEXT.fields_by_name['namespace_options'].message_type = _NAMESPACEOPTION
_LINUXSANDBOXSECURITYCONTEXT.fields_by_name['selinux_options'].message_type = _SELINUXOPTION
_LINUXSANDBOXSECURITYCONTEXT.fields_by_name['run_as_user'].message_type = _INT64VALUE
_LINUXPODSANDBOXCONFIG.fields_by_name['security_context'].message_type = _LINUXSANDBOXSECURITYCONTEXT
_PODSANDBOXCONFIG_LABELSENTRY.containing_type = _PODSANDBOXCONFIG
_PODSANDBOXCONFIG_ANNOTATIONSENTRY.containing_type = _PODSANDBOXCONFIG
_PODSANDBOXCONFIG.fields_by_name['metadata'].message_type = _PODSANDBOXMETADATA
_PODSANDBOXCONFIG.fields_by_name['dns_config'].message_type = _DNSCONFIG
_PODSANDBOXCONFIG.fields_by_name['port_mappings'].message_type = _PORTMAPPING
_PODSANDBOXCONFIG.fields_by_name['labels'].message_type = _PODSANDBOXCONFIG_LABELSENTRY
_PODSANDBOXCONFIG.fields_by_name['annotations'].message_type = _PODSANDBOXCONFIG_ANNOTATIONSENTRY
_PODSANDBOXCONFIG.fields_by_name['linux'].message_type = _LINUXPODSANDBOXCONFIG
_RUNPODSANDBOXREQUEST.fields_by_name['config'].message_type = _PODSANDBOXCONFIG
_NAMESPACE.fields_by_name['options'].message_type = _NAMESPACEOPTION
_LINUXPODSANDBOXSTATUS.fields_by_name['namespaces'].message_type = _NAMESPACE
_PODSANDBOXSTATUS_LABELSENTRY.containing_type = _PODSANDBOXSTATUS
_PODSANDBOXSTATUS_ANNOTATIONSENTRY.containing_type = _PODSANDBOXSTATUS
_PODSANDBOXSTATUS.fields_by_name['metadata'].message_type = _PODSANDBOXMETADATA
_PODSANDBOXSTATUS.fields_by_name['state'].enum_type = _PODSANDBOXSTATE
_PODSANDBOXSTATUS.fields_by_name['network'].message_type = _PODSANDBOXNETWORKSTATUS
_PODSANDBOXSTATUS.fields_by_name['linux'].message_type = _LINUXPODSANDBOXSTATUS
_PODSANDBOXSTATUS.fields_by_name['labels'].message_type = _PODSANDBOXSTATUS_LABELSENTRY
_PODSANDBOXSTATUS.fields_by_name['annotations'].message_type = _PODSANDBOXSTATUS_ANNOTATIONSENTRY
_PODSANDBOXSTATUSRESPONSE.fields_by_name['status'].message_type = _PODSANDBOXSTATUS
_PODSANDBOXSTATEVALUE.fields_by_name['state'].enum_type = _PODSANDBOXSTATE
_PODSANDBOXFILTER_LABELSELECTORENTRY.containing_type = _PODSANDBOXFILTER
_PODSANDBOXFILTER.fields_by_name['state'].message_type = _PODSANDBOXSTATEVALUE
_PODSANDBOXFILTER.fields_by_name['label_selector'].message_type = _PODSANDBOXFILTER_LABELSELECTORENTRY
_LISTPODSANDBOXREQUEST.fields_by_name['filter'].message_type = _PODSANDBOXFILTER
_PODSANDBOX_LABELSENTRY.containing_type = _PODSANDBOX
_PODSANDBOX_ANNOTATIONSENTRY.containing_type = _PODSANDBOX
_PODSANDBOX.fields_by_name['metadata'].message_type = _PODSANDBOXMETADATA
_PODSANDBOX.fields_by_name['state'].enum_type = _PODSANDBOXSTATE
_PODSANDBOX.fields_by_name['labels'].message_type = _PODSANDBOX_LABELSENTRY
_PODSANDBOX.fields_by_name['annotations'].message_type = _PODSANDBOX_ANNOTATIONSENTRY
_LISTPODSANDBOXRESPONSE.fields_by_name['items'].message_type = _PODSANDBOX
_LINUXCONTAINERSECURITYCONTEXT.fields_by_name['capabilities'].message_type = _CAPABILITY
_LINUXCONTAINERSECURITYCONTEXT.fields_by_name['namespace_options'].message_type = _NAMESPACEOPTION
_LINUXCONTAINERSECURITYCONTEXT.fields_by_name['selinux_options'].message_type = _SELINUXOPTION
_LINUXCONTAINERSECURITYCONTEXT.fields_by_name['run_as_user'].message_type = _INT64VALUE
_LINUXCONTAINERCONFIG.fields_by_name['resources'].message_type = _LINUXCONTAINERRESOURCES
_LINUXCONTAINERCONFIG.fields_by_name['security_context'].message_type = _LINUXCONTAINERSECURITYCONTEXT
_CONTAINERCONFIG_LABELSENTRY.containing_type = _CONTAINERCONFIG
_CONTAINERCONFIG_ANNOTATIONSENTRY.containing_type = _CONTAINERCONFIG
_CONTAINERCONFIG.fields_by_name['metadata'].message_type = _CONTAINERMETADATA
_CONTAINERCONFIG.fields_by_name['image'].message_type = _IMAGESPEC
_CONTAINERCONFIG.fields_by_name['envs'].message_type = _KEYVALUE
_CONTAINERCONFIG.fields_by_name['mounts'].message_type = _MOUNT
_CONTAINERCONFIG.fields_by_name['devices'].message_type = _DEVICE
_CONTAINERCONFIG.fields_by_name['labels'].message_type = _CONTAINERCONFIG_LABELSENTRY
_CONTAINERCONFIG.fields_by_name['annotations'].message_type = _CONTAINERCONFIG_ANNOTATIONSENTRY
_CONTAINERCONFIG.fields_by_name['linux'].message_type = _LINUXCONTAINERCONFIG
_CREATECONTAINERREQUEST.fields_by_name['config'].message_type = _CONTAINERCONFIG
_CREATECONTAINERREQUEST.fields_by_name['sandbox_config'].message_type = _PODSANDBOXCONFIG
_CONTAINERSTATEVALUE.fields_by_name['state'].enum_type = _CONTAINERSTATE
_CONTAINERFILTER_LABELSELECTORENTRY.containing_type = _CONTAINERFILTER
_CONTAINERFILTER.fields_by_name['state'].message_type = _CONTAINERSTATEVALUE
_CONTAINERFILTER.fields_by_name['label_selector'].message_type = _CONTAINERFILTER_LABELSELECTORENTRY
_LISTCONTAINERSREQUEST.fields_by_name['filter'].message_type = _CONTAINERFILTER
_CONTAINER_LABELSENTRY.containing_type = _CONTAINER
_CONTAINER_ANNOTATIONSENTRY.containing_type = _CONTAINER
_CONTAINER.fields_by_name['metadata'].message_type = _CONTAINERMETADATA
_CONTAINER.fields_by_name['image'].message_type = _IMAGESPEC
_CONTAINER.fields_by_name['state'].enum_type = _CONTAINERSTATE
_CONTAINER.fields_by_name['labels'].message_type = _CONTAINER_LABELSENTRY
_CONTAINER.fields_by_name['annotations'].message_type = _CONTAINER_ANNOTATIONSENTRY
_LISTCONTAINERSRESPONSE.fields_by_name['containers'].message_type = _CONTAINER
_CONTAINERSTATUS_LABELSENTRY.containing_type = _CONTAINERSTATUS
_CONTAINERSTATUS_ANNOTATIONSENTRY.containing_type = _CONTAINERSTATUS
_CONTAINERSTATUS.fields_by_name['metadata'].message_type = _CONTAINERMETADATA
_CONTAINERSTATUS.fields_by_name['state'].enum_type = _CONTAINERSTATE
_CONTAINERSTATUS.fields_by_name['image'].message_type = _IMAGESPEC
_CONTAINERSTATUS.fields_by_name['labels'].message_type = _CONTAINERSTATUS_LABELSENTRY
_CONTAINERSTATUS.fields_by_name['annotations'].message_type = _CONTAINERSTATUS_ANNOTATIONSENTRY
_CONTAINERSTATUS.fields_by_name['mounts'].message_type = _MOUNT
_CONTAINERSTATUSRESPONSE.fields_by_name['status'].message_type = _CONTAINERSTATUS
_IMAGEFILTER.fields_by_name['image'].message_type = _IMAGESPEC
_LISTIMAGESREQUEST.fields_by_name['filter'].message_type = _IMAGEFILTER
_IMAGE.fields_by_name['uid'].message_type = _INT64VALUE
_LISTIMAGESRESPONSE.fields_by_name['images'].message_type = _IMAGE
_IMAGESTATUSREQUEST.fields_by_name['image'].message_type = _IMAGESPEC
_IMAGESTATUSRESPONSE.fields_by_name['image'].message_type = _IMAGE
_PULLIMAGEREQUEST.fields_by_name['image'].message_type = _IMAGESPEC
_PULLIMAGEREQUEST.fields_by_name['auth'].message_type = _AUTHCONFIG
_PULLIMAGEREQUEST.fields_by_name['sandbox_config'].message_type = _PODSANDBOXCONFIG
_REMOVEIMAGEREQUEST.fields_by_name['image'].message_type = _IMAGESPEC
_RUNTIMECONFIG.fields_by_name['network_config'].message_type = _NETWORKCONFIG
_UPDATERUNTIMECONFIGREQUEST.fields_by_name['runtime_config'].message_type = _RUNTIMECONFIG
_RUNTIMESTATUS.fields_by_name['conditions'].message_type = _RUNTIMECONDITION
_STATUSRESPONSE.fields_by_name['status'].message_type = _RUNTIMESTATUS
DESCRIPTOR.message_types_by_name['VersionRequest'] = _VERSIONREQUEST
DESCRIPTOR.message_types_by_name['VersionResponse'] = _VERSIONRESPONSE
DESCRIPTOR.message_types_by_name['DNSConfig'] = _DNSCONFIG
DESCRIPTOR.message_types_by_name['PortMapping'] = _PORTMAPPING
DESCRIPTOR.message_types_by_name['Mount'] = _MOUNT
DESCRIPTOR.message_types_by_name['NamespaceOption'] = _NAMESPACEOPTION
DESCRIPTOR.message_types_by_name['Int64Value'] = _INT64VALUE
DESCRIPTOR.message_types_by_name['LinuxSandboxSecurityContext'] = _LINUXSANDBOXSECURITYCONTEXT
DESCRIPTOR.message_types_by_name['LinuxPodSandboxConfig'] = _LINUXPODSANDBOXCONFIG
DESCRIPTOR.message_types_by_name['PodSandboxMetadata'] = _PODSANDBOXMETADATA
DESCRIPTOR.message_types_by_name['PodSandboxConfig'] = _PODSANDBOXCONFIG
DESCRIPTOR.message_types_by_name['RunPodSandboxRequest'] = _RUNPODSANDBOXREQUEST
DESCRIPTOR.message_types_by_name['RunPodSandboxResponse'] = _RUNPODSANDBOXRESPONSE
DESCRIPTOR.message_types_by_name['StopPodSandboxRequest'] = _STOPPODSANDBOXREQUEST
DESCRIPTOR.message_types_by_name['StopPodSandboxResponse'] = _STOPPODSANDBOXRESPONSE
DESCRIPTOR.message_types_by_name['RemovePodSandboxRequest'] = _REMOVEPODSANDBOXREQUEST
DESCRIPTOR.message_types_by_name['RemovePodSandboxResponse'] = _REMOVEPODSANDBOXRESPONSE
DESCRIPTOR.message_types_by_name['PodSandboxStatusRequest'] = _PODSANDBOXSTATUSREQUEST
DESCRIPTOR.message_types_by_name['PodSandboxNetworkStatus'] = _PODSANDBOXNETWORKSTATUS
DESCRIPTOR.message_types_by_name['Namespace'] = _NAMESPACE
DESCRIPTOR.message_types_by_name['LinuxPodSandboxStatus'] = _LINUXPODSANDBOXSTATUS
DESCRIPTOR.message_types_by_name['PodSandboxStatus'] = _PODSANDBOXSTATUS
DESCRIPTOR.message_types_by_name['PodSandboxStatusResponse'] = _PODSANDBOXSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['PodSandboxStateValue'] = _PODSANDBOXSTATEVALUE
DESCRIPTOR.message_types_by_name['PodSandboxFilter'] = _PODSANDBOXFILTER
DESCRIPTOR.message_types_by_name['ListPodSandboxRequest'] = _LISTPODSANDBOXREQUEST
DESCRIPTOR.message_types_by_name['PodSandbox'] = _PODSANDBOX
DESCRIPTOR.message_types_by_name['ListPodSandboxResponse'] = _LISTPODSANDBOXRESPONSE
DESCRIPTOR.message_types_by_name['ImageSpec'] = _IMAGESPEC
DESCRIPTOR.message_types_by_name['KeyValue'] = _KEYVALUE
DESCRIPTOR.message_types_by_name['LinuxContainerResources'] = _LINUXCONTAINERRESOURCES
DESCRIPTOR.message_types_by_name['SELinuxOption'] = _SELINUXOPTION
DESCRIPTOR.message_types_by_name['Capability'] = _CAPABILITY
DESCRIPTOR.message_types_by_name['LinuxContainerSecurityContext'] = _LINUXCONTAINERSECURITYCONTEXT
DESCRIPTOR.message_types_by_name['LinuxContainerConfig'] = _LINUXCONTAINERCONFIG
DESCRIPTOR.message_types_by_name['ContainerMetadata'] = _CONTAINERMETADATA
DESCRIPTOR.message_types_by_name['Device'] = _DEVICE
DESCRIPTOR.message_types_by_name['ContainerConfig'] = _CONTAINERCONFIG
DESCRIPTOR.message_types_by_name['CreateContainerRequest'] = _CREATECONTAINERREQUEST
DESCRIPTOR.message_types_by_name['CreateContainerResponse'] = _CREATECONTAINERRESPONSE
DESCRIPTOR.message_types_by_name['StartContainerRequest'] = _STARTCONTAINERREQUEST
DESCRIPTOR.message_types_by_name['StartContainerResponse'] = _STARTCONTAINERRESPONSE
DESCRIPTOR.message_types_by_name['StopContainerRequest'] = _STOPCONTAINERREQUEST
DESCRIPTOR.message_types_by_name['StopContainerResponse'] = _STOPCONTAINERRESPONSE
DESCRIPTOR.message_types_by_name['RemoveContainerRequest'] = _REMOVECONTAINERREQUEST
DESCRIPTOR.message_types_by_name['RemoveContainerResponse'] = _REMOVECONTAINERRESPONSE
DESCRIPTOR.message_types_by_name['ContainerStateValue'] = _CONTAINERSTATEVALUE
DESCRIPTOR.message_types_by_name['ContainerFilter'] = _CONTAINERFILTER
DESCRIPTOR.message_types_by_name['ListContainersRequest'] = _LISTCONTAINERSREQUEST
DESCRIPTOR.message_types_by_name['Container'] = _CONTAINER
DESCRIPTOR.message_types_by_name['ListContainersResponse'] = _LISTCONTAINERSRESPONSE
DESCRIPTOR.message_types_by_name['ContainerStatusRequest'] = _CONTAINERSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ContainerStatus'] = _CONTAINERSTATUS
DESCRIPTOR.message_types_by_name['ContainerStatusResponse'] = _CONTAINERSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['ExecSyncRequest'] = _EXECSYNCREQUEST
DESCRIPTOR.message_types_by_name['ExecSyncResponse'] = _EXECSYNCRESPONSE
DESCRIPTOR.message_types_by_name['ExecRequest'] = _EXECREQUEST
DESCRIPTOR.message_types_by_name['ExecResponse'] = _EXECRESPONSE
DESCRIPTOR.message_types_by_name['AttachRequest'] = _ATTACHREQUEST
DESCRIPTOR.message_types_by_name['AttachResponse'] = _ATTACHRESPONSE
DESCRIPTOR.message_types_by_name['PortForwardRequest'] = _PORTFORWARDREQUEST
DESCRIPTOR.message_types_by_name['PortForwardResponse'] = _PORTFORWARDRESPONSE
DESCRIPTOR.message_types_by_name['ImageFilter'] = _IMAGEFILTER
DESCRIPTOR.message_types_by_name['ListImagesRequest'] = _LISTIMAGESREQUEST
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
DESCRIPTOR.message_types_by_name['ListImagesResponse'] = _LISTIMAGESRESPONSE
DESCRIPTOR.message_types_by_name['ImageStatusRequest'] = _IMAGESTATUSREQUEST
DESCRIPTOR.message_types_by_name['ImageStatusResponse'] = _IMAGESTATUSRESPONSE
DESCRIPTOR.message_types_by_name['AuthConfig'] = _AUTHCONFIG
DESCRIPTOR.message_types_by_name['PullImageRequest'] = _PULLIMAGEREQUEST
DESCRIPTOR.message_types_by_name['PullImageResponse'] = _PULLIMAGERESPONSE
DESCRIPTOR.message_types_by_name['RemoveImageRequest'] = _REMOVEIMAGEREQUEST
DESCRIPTOR.message_types_by_name['RemoveImageResponse'] = _REMOVEIMAGERESPONSE
DESCRIPTOR.message_types_by_name['NetworkConfig'] = _NETWORKCONFIG
DESCRIPTOR.message_types_by_name['RuntimeConfig'] = _RUNTIMECONFIG
DESCRIPTOR.message_types_by_name['UpdateRuntimeConfigRequest'] = _UPDATERUNTIMECONFIGREQUEST
DESCRIPTOR.message_types_by_name['UpdateRuntimeConfigResponse'] = _UPDATERUNTIMECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['RuntimeCondition'] = _RUNTIMECONDITION
DESCRIPTOR.message_types_by_name['RuntimeStatus'] = _RUNTIMESTATUS
DESCRIPTOR.message_types_by_name['StatusRequest'] = _STATUSREQUEST
DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
DESCRIPTOR.enum_types_by_name['Protocol'] = _PROTOCOL
DESCRIPTOR.enum_types_by_name['PodSandboxState'] = _PODSANDBOXSTATE
DESCRIPTOR.enum_types_by_name['ContainerState'] = _CONTAINERSTATE

VersionRequest = _reflection.GeneratedProtocolMessageType('VersionRequest', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.VersionRequest)
  ))
_sym_db.RegisterMessage(VersionRequest)

VersionResponse = _reflection.GeneratedProtocolMessageType('VersionResponse', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.VersionResponse)
  ))
_sym_db.RegisterMessage(VersionResponse)

DNSConfig = _reflection.GeneratedProtocolMessageType('DNSConfig', (_message.Message,), dict(
  DESCRIPTOR = _DNSCONFIG,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.DNSConfig)
  ))
_sym_db.RegisterMessage(DNSConfig)

PortMapping = _reflection.GeneratedProtocolMessageType('PortMapping', (_message.Message,), dict(
  DESCRIPTOR = _PORTMAPPING,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PortMapping)
  ))
_sym_db.RegisterMessage(PortMapping)

Mount = _reflection.GeneratedProtocolMessageType('Mount', (_message.Message,), dict(
  DESCRIPTOR = _MOUNT,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.Mount)
  ))
_sym_db.RegisterMessage(Mount)

NamespaceOption = _reflection.GeneratedProtocolMessageType('NamespaceOption', (_message.Message,), dict(
  DESCRIPTOR = _NAMESPACEOPTION,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.NamespaceOption)
  ))
_sym_db.RegisterMessage(NamespaceOption)

Int64Value = _reflection.GeneratedProtocolMessageType('Int64Value', (_message.Message,), dict(
  DESCRIPTOR = _INT64VALUE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.Int64Value)
  ))
_sym_db.RegisterMessage(Int64Value)

LinuxSandboxSecurityContext = _reflection.GeneratedProtocolMessageType('LinuxSandboxSecurityContext', (_message.Message,), dict(
  DESCRIPTOR = _LINUXSANDBOXSECURITYCONTEXT,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.LinuxSandboxSecurityContext)
  ))
_sym_db.RegisterMessage(LinuxSandboxSecurityContext)

LinuxPodSandboxConfig = _reflection.GeneratedProtocolMessageType('LinuxPodSandboxConfig', (_message.Message,), dict(
  DESCRIPTOR = _LINUXPODSANDBOXCONFIG,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.LinuxPodSandboxConfig)
  ))
_sym_db.RegisterMessage(LinuxPodSandboxConfig)

PodSandboxMetadata = _reflection.GeneratedProtocolMessageType('PodSandboxMetadata', (_message.Message,), dict(
  DESCRIPTOR = _PODSANDBOXMETADATA,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PodSandboxMetadata)
  ))
_sym_db.RegisterMessage(PodSandboxMetadata)

PodSandboxConfig = _reflection.GeneratedProtocolMessageType('PodSandboxConfig', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PODSANDBOXCONFIG_LABELSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.PodSandboxConfig.LabelsEntry)
    ))
  ,

  AnnotationsEntry = _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PODSANDBOXCONFIG_ANNOTATIONSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.PodSandboxConfig.AnnotationsEntry)
    ))
  ,
  DESCRIPTOR = _PODSANDBOXCONFIG,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PodSandboxConfig)
  ))
_sym_db.RegisterMessage(PodSandboxConfig)
_sym_db.RegisterMessage(PodSandboxConfig.LabelsEntry)
_sym_db.RegisterMessage(PodSandboxConfig.AnnotationsEntry)

RunPodSandboxRequest = _reflection.GeneratedProtocolMessageType('RunPodSandboxRequest', (_message.Message,), dict(
  DESCRIPTOR = _RUNPODSANDBOXREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RunPodSandboxRequest)
  ))
_sym_db.RegisterMessage(RunPodSandboxRequest)

RunPodSandboxResponse = _reflection.GeneratedProtocolMessageType('RunPodSandboxResponse', (_message.Message,), dict(
  DESCRIPTOR = _RUNPODSANDBOXRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RunPodSandboxResponse)
  ))
_sym_db.RegisterMessage(RunPodSandboxResponse)

StopPodSandboxRequest = _reflection.GeneratedProtocolMessageType('StopPodSandboxRequest', (_message.Message,), dict(
  DESCRIPTOR = _STOPPODSANDBOXREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.StopPodSandboxRequest)
  ))
_sym_db.RegisterMessage(StopPodSandboxRequest)

StopPodSandboxResponse = _reflection.GeneratedProtocolMessageType('StopPodSandboxResponse', (_message.Message,), dict(
  DESCRIPTOR = _STOPPODSANDBOXRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.StopPodSandboxResponse)
  ))
_sym_db.RegisterMessage(StopPodSandboxResponse)

RemovePodSandboxRequest = _reflection.GeneratedProtocolMessageType('RemovePodSandboxRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEPODSANDBOXREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RemovePodSandboxRequest)
  ))
_sym_db.RegisterMessage(RemovePodSandboxRequest)

RemovePodSandboxResponse = _reflection.GeneratedProtocolMessageType('RemovePodSandboxResponse', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEPODSANDBOXRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RemovePodSandboxResponse)
  ))
_sym_db.RegisterMessage(RemovePodSandboxResponse)

PodSandboxStatusRequest = _reflection.GeneratedProtocolMessageType('PodSandboxStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _PODSANDBOXSTATUSREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PodSandboxStatusRequest)
  ))
_sym_db.RegisterMessage(PodSandboxStatusRequest)

PodSandboxNetworkStatus = _reflection.GeneratedProtocolMessageType('PodSandboxNetworkStatus', (_message.Message,), dict(
  DESCRIPTOR = _PODSANDBOXNETWORKSTATUS,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PodSandboxNetworkStatus)
  ))
_sym_db.RegisterMessage(PodSandboxNetworkStatus)

Namespace = _reflection.GeneratedProtocolMessageType('Namespace', (_message.Message,), dict(
  DESCRIPTOR = _NAMESPACE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.Namespace)
  ))
_sym_db.RegisterMessage(Namespace)

LinuxPodSandboxStatus = _reflection.GeneratedProtocolMessageType('LinuxPodSandboxStatus', (_message.Message,), dict(
  DESCRIPTOR = _LINUXPODSANDBOXSTATUS,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.LinuxPodSandboxStatus)
  ))
_sym_db.RegisterMessage(LinuxPodSandboxStatus)

PodSandboxStatus = _reflection.GeneratedProtocolMessageType('PodSandboxStatus', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PODSANDBOXSTATUS_LABELSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.PodSandboxStatus.LabelsEntry)
    ))
  ,

  AnnotationsEntry = _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PODSANDBOXSTATUS_ANNOTATIONSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.PodSandboxStatus.AnnotationsEntry)
    ))
  ,
  DESCRIPTOR = _PODSANDBOXSTATUS,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PodSandboxStatus)
  ))
_sym_db.RegisterMessage(PodSandboxStatus)
_sym_db.RegisterMessage(PodSandboxStatus.LabelsEntry)
_sym_db.RegisterMessage(PodSandboxStatus.AnnotationsEntry)

PodSandboxStatusResponse = _reflection.GeneratedProtocolMessageType('PodSandboxStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _PODSANDBOXSTATUSRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PodSandboxStatusResponse)
  ))
_sym_db.RegisterMessage(PodSandboxStatusResponse)

PodSandboxStateValue = _reflection.GeneratedProtocolMessageType('PodSandboxStateValue', (_message.Message,), dict(
  DESCRIPTOR = _PODSANDBOXSTATEVALUE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PodSandboxStateValue)
  ))
_sym_db.RegisterMessage(PodSandboxStateValue)

PodSandboxFilter = _reflection.GeneratedProtocolMessageType('PodSandboxFilter', (_message.Message,), dict(

  LabelSelectorEntry = _reflection.GeneratedProtocolMessageType('LabelSelectorEntry', (_message.Message,), dict(
    DESCRIPTOR = _PODSANDBOXFILTER_LABELSELECTORENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.PodSandboxFilter.LabelSelectorEntry)
    ))
  ,
  DESCRIPTOR = _PODSANDBOXFILTER,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PodSandboxFilter)
  ))
_sym_db.RegisterMessage(PodSandboxFilter)
_sym_db.RegisterMessage(PodSandboxFilter.LabelSelectorEntry)

ListPodSandboxRequest = _reflection.GeneratedProtocolMessageType('ListPodSandboxRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPODSANDBOXREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ListPodSandboxRequest)
  ))
_sym_db.RegisterMessage(ListPodSandboxRequest)

PodSandbox = _reflection.GeneratedProtocolMessageType('PodSandbox', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PODSANDBOX_LABELSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.PodSandbox.LabelsEntry)
    ))
  ,

  AnnotationsEntry = _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), dict(
    DESCRIPTOR = _PODSANDBOX_ANNOTATIONSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.PodSandbox.AnnotationsEntry)
    ))
  ,
  DESCRIPTOR = _PODSANDBOX,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PodSandbox)
  ))
_sym_db.RegisterMessage(PodSandbox)
_sym_db.RegisterMessage(PodSandbox.LabelsEntry)
_sym_db.RegisterMessage(PodSandbox.AnnotationsEntry)

ListPodSandboxResponse = _reflection.GeneratedProtocolMessageType('ListPodSandboxResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPODSANDBOXRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ListPodSandboxResponse)
  ))
_sym_db.RegisterMessage(ListPodSandboxResponse)

ImageSpec = _reflection.GeneratedProtocolMessageType('ImageSpec', (_message.Message,), dict(
  DESCRIPTOR = _IMAGESPEC,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ImageSpec)
  ))
_sym_db.RegisterMessage(ImageSpec)

KeyValue = _reflection.GeneratedProtocolMessageType('KeyValue', (_message.Message,), dict(
  DESCRIPTOR = _KEYVALUE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.KeyValue)
  ))
_sym_db.RegisterMessage(KeyValue)

LinuxContainerResources = _reflection.GeneratedProtocolMessageType('LinuxContainerResources', (_message.Message,), dict(
  DESCRIPTOR = _LINUXCONTAINERRESOURCES,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.LinuxContainerResources)
  ))
_sym_db.RegisterMessage(LinuxContainerResources)

SELinuxOption = _reflection.GeneratedProtocolMessageType('SELinuxOption', (_message.Message,), dict(
  DESCRIPTOR = _SELINUXOPTION,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.SELinuxOption)
  ))
_sym_db.RegisterMessage(SELinuxOption)

Capability = _reflection.GeneratedProtocolMessageType('Capability', (_message.Message,), dict(
  DESCRIPTOR = _CAPABILITY,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.Capability)
  ))
_sym_db.RegisterMessage(Capability)

LinuxContainerSecurityContext = _reflection.GeneratedProtocolMessageType('LinuxContainerSecurityContext', (_message.Message,), dict(
  DESCRIPTOR = _LINUXCONTAINERSECURITYCONTEXT,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.LinuxContainerSecurityContext)
  ))
_sym_db.RegisterMessage(LinuxContainerSecurityContext)

LinuxContainerConfig = _reflection.GeneratedProtocolMessageType('LinuxContainerConfig', (_message.Message,), dict(
  DESCRIPTOR = _LINUXCONTAINERCONFIG,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.LinuxContainerConfig)
  ))
_sym_db.RegisterMessage(LinuxContainerConfig)

ContainerMetadata = _reflection.GeneratedProtocolMessageType('ContainerMetadata', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERMETADATA,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ContainerMetadata)
  ))
_sym_db.RegisterMessage(ContainerMetadata)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), dict(
  DESCRIPTOR = _DEVICE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.Device)
  ))
_sym_db.RegisterMessage(Device)

ContainerConfig = _reflection.GeneratedProtocolMessageType('ContainerConfig', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONTAINERCONFIG_LABELSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.ContainerConfig.LabelsEntry)
    ))
  ,

  AnnotationsEntry = _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONTAINERCONFIG_ANNOTATIONSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.ContainerConfig.AnnotationsEntry)
    ))
  ,
  DESCRIPTOR = _CONTAINERCONFIG,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ContainerConfig)
  ))
_sym_db.RegisterMessage(ContainerConfig)
_sym_db.RegisterMessage(ContainerConfig.LabelsEntry)
_sym_db.RegisterMessage(ContainerConfig.AnnotationsEntry)

CreateContainerRequest = _reflection.GeneratedProtocolMessageType('CreateContainerRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATECONTAINERREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.CreateContainerRequest)
  ))
_sym_db.RegisterMessage(CreateContainerRequest)

CreateContainerResponse = _reflection.GeneratedProtocolMessageType('CreateContainerResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATECONTAINERRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.CreateContainerResponse)
  ))
_sym_db.RegisterMessage(CreateContainerResponse)

StartContainerRequest = _reflection.GeneratedProtocolMessageType('StartContainerRequest', (_message.Message,), dict(
  DESCRIPTOR = _STARTCONTAINERREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.StartContainerRequest)
  ))
_sym_db.RegisterMessage(StartContainerRequest)

StartContainerResponse = _reflection.GeneratedProtocolMessageType('StartContainerResponse', (_message.Message,), dict(
  DESCRIPTOR = _STARTCONTAINERRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.StartContainerResponse)
  ))
_sym_db.RegisterMessage(StartContainerResponse)

StopContainerRequest = _reflection.GeneratedProtocolMessageType('StopContainerRequest', (_message.Message,), dict(
  DESCRIPTOR = _STOPCONTAINERREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.StopContainerRequest)
  ))
_sym_db.RegisterMessage(StopContainerRequest)

StopContainerResponse = _reflection.GeneratedProtocolMessageType('StopContainerResponse', (_message.Message,), dict(
  DESCRIPTOR = _STOPCONTAINERRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.StopContainerResponse)
  ))
_sym_db.RegisterMessage(StopContainerResponse)

RemoveContainerRequest = _reflection.GeneratedProtocolMessageType('RemoveContainerRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOVECONTAINERREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RemoveContainerRequest)
  ))
_sym_db.RegisterMessage(RemoveContainerRequest)

RemoveContainerResponse = _reflection.GeneratedProtocolMessageType('RemoveContainerResponse', (_message.Message,), dict(
  DESCRIPTOR = _REMOVECONTAINERRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RemoveContainerResponse)
  ))
_sym_db.RegisterMessage(RemoveContainerResponse)

ContainerStateValue = _reflection.GeneratedProtocolMessageType('ContainerStateValue', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERSTATEVALUE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ContainerStateValue)
  ))
_sym_db.RegisterMessage(ContainerStateValue)

ContainerFilter = _reflection.GeneratedProtocolMessageType('ContainerFilter', (_message.Message,), dict(

  LabelSelectorEntry = _reflection.GeneratedProtocolMessageType('LabelSelectorEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONTAINERFILTER_LABELSELECTORENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.ContainerFilter.LabelSelectorEntry)
    ))
  ,
  DESCRIPTOR = _CONTAINERFILTER,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ContainerFilter)
  ))
_sym_db.RegisterMessage(ContainerFilter)
_sym_db.RegisterMessage(ContainerFilter.LabelSelectorEntry)

ListContainersRequest = _reflection.GeneratedProtocolMessageType('ListContainersRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTCONTAINERSREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ListContainersRequest)
  ))
_sym_db.RegisterMessage(ListContainersRequest)

Container = _reflection.GeneratedProtocolMessageType('Container', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONTAINER_LABELSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.Container.LabelsEntry)
    ))
  ,

  AnnotationsEntry = _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONTAINER_ANNOTATIONSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.Container.AnnotationsEntry)
    ))
  ,
  DESCRIPTOR = _CONTAINER,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.Container)
  ))
_sym_db.RegisterMessage(Container)
_sym_db.RegisterMessage(Container.LabelsEntry)
_sym_db.RegisterMessage(Container.AnnotationsEntry)

ListContainersResponse = _reflection.GeneratedProtocolMessageType('ListContainersResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTCONTAINERSRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ListContainersResponse)
  ))
_sym_db.RegisterMessage(ListContainersResponse)

ContainerStatusRequest = _reflection.GeneratedProtocolMessageType('ContainerStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERSTATUSREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ContainerStatusRequest)
  ))
_sym_db.RegisterMessage(ContainerStatusRequest)

ContainerStatus = _reflection.GeneratedProtocolMessageType('ContainerStatus', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONTAINERSTATUS_LABELSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.ContainerStatus.LabelsEntry)
    ))
  ,

  AnnotationsEntry = _reflection.GeneratedProtocolMessageType('AnnotationsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONTAINERSTATUS_ANNOTATIONSENTRY,
    __module__ = 'api_pb2'
    # @@protoc_insertion_point(class_scope:runtime.ContainerStatus.AnnotationsEntry)
    ))
  ,
  DESCRIPTOR = _CONTAINERSTATUS,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ContainerStatus)
  ))
_sym_db.RegisterMessage(ContainerStatus)
_sym_db.RegisterMessage(ContainerStatus.LabelsEntry)
_sym_db.RegisterMessage(ContainerStatus.AnnotationsEntry)

ContainerStatusResponse = _reflection.GeneratedProtocolMessageType('ContainerStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERSTATUSRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ContainerStatusResponse)
  ))
_sym_db.RegisterMessage(ContainerStatusResponse)

ExecSyncRequest = _reflection.GeneratedProtocolMessageType('ExecSyncRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECSYNCREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ExecSyncRequest)
  ))
_sym_db.RegisterMessage(ExecSyncRequest)

ExecSyncResponse = _reflection.GeneratedProtocolMessageType('ExecSyncResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXECSYNCRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ExecSyncResponse)
  ))
_sym_db.RegisterMessage(ExecSyncResponse)

ExecRequest = _reflection.GeneratedProtocolMessageType('ExecRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ExecRequest)
  ))
_sym_db.RegisterMessage(ExecRequest)

ExecResponse = _reflection.GeneratedProtocolMessageType('ExecResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXECRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ExecResponse)
  ))
_sym_db.RegisterMessage(ExecResponse)

AttachRequest = _reflection.GeneratedProtocolMessageType('AttachRequest', (_message.Message,), dict(
  DESCRIPTOR = _ATTACHREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.AttachRequest)
  ))
_sym_db.RegisterMessage(AttachRequest)

AttachResponse = _reflection.GeneratedProtocolMessageType('AttachResponse', (_message.Message,), dict(
  DESCRIPTOR = _ATTACHRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.AttachResponse)
  ))
_sym_db.RegisterMessage(AttachResponse)

PortForwardRequest = _reflection.GeneratedProtocolMessageType('PortForwardRequest', (_message.Message,), dict(
  DESCRIPTOR = _PORTFORWARDREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PortForwardRequest)
  ))
_sym_db.RegisterMessage(PortForwardRequest)

PortForwardResponse = _reflection.GeneratedProtocolMessageType('PortForwardResponse', (_message.Message,), dict(
  DESCRIPTOR = _PORTFORWARDRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PortForwardResponse)
  ))
_sym_db.RegisterMessage(PortForwardResponse)

ImageFilter = _reflection.GeneratedProtocolMessageType('ImageFilter', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEFILTER,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ImageFilter)
  ))
_sym_db.RegisterMessage(ImageFilter)

ListImagesRequest = _reflection.GeneratedProtocolMessageType('ListImagesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTIMAGESREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ListImagesRequest)
  ))
_sym_db.RegisterMessage(ListImagesRequest)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), dict(
  DESCRIPTOR = _IMAGE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.Image)
  ))
_sym_db.RegisterMessage(Image)

ListImagesResponse = _reflection.GeneratedProtocolMessageType('ListImagesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTIMAGESRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ListImagesResponse)
  ))
_sym_db.RegisterMessage(ListImagesResponse)

ImageStatusRequest = _reflection.GeneratedProtocolMessageType('ImageStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _IMAGESTATUSREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ImageStatusRequest)
  ))
_sym_db.RegisterMessage(ImageStatusRequest)

ImageStatusResponse = _reflection.GeneratedProtocolMessageType('ImageStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _IMAGESTATUSRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.ImageStatusResponse)
  ))
_sym_db.RegisterMessage(ImageStatusResponse)

AuthConfig = _reflection.GeneratedProtocolMessageType('AuthConfig', (_message.Message,), dict(
  DESCRIPTOR = _AUTHCONFIG,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.AuthConfig)
  ))
_sym_db.RegisterMessage(AuthConfig)

PullImageRequest = _reflection.GeneratedProtocolMessageType('PullImageRequest', (_message.Message,), dict(
  DESCRIPTOR = _PULLIMAGEREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PullImageRequest)
  ))
_sym_db.RegisterMessage(PullImageRequest)

PullImageResponse = _reflection.GeneratedProtocolMessageType('PullImageResponse', (_message.Message,), dict(
  DESCRIPTOR = _PULLIMAGERESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.PullImageResponse)
  ))
_sym_db.RegisterMessage(PullImageResponse)

RemoveImageRequest = _reflection.GeneratedProtocolMessageType('RemoveImageRequest', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEIMAGEREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RemoveImageRequest)
  ))
_sym_db.RegisterMessage(RemoveImageRequest)

RemoveImageResponse = _reflection.GeneratedProtocolMessageType('RemoveImageResponse', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEIMAGERESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RemoveImageResponse)
  ))
_sym_db.RegisterMessage(RemoveImageResponse)

NetworkConfig = _reflection.GeneratedProtocolMessageType('NetworkConfig', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKCONFIG,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.NetworkConfig)
  ))
_sym_db.RegisterMessage(NetworkConfig)

RuntimeConfig = _reflection.GeneratedProtocolMessageType('RuntimeConfig', (_message.Message,), dict(
  DESCRIPTOR = _RUNTIMECONFIG,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RuntimeConfig)
  ))
_sym_db.RegisterMessage(RuntimeConfig)

UpdateRuntimeConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateRuntimeConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATERUNTIMECONFIGREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.UpdateRuntimeConfigRequest)
  ))
_sym_db.RegisterMessage(UpdateRuntimeConfigRequest)

UpdateRuntimeConfigResponse = _reflection.GeneratedProtocolMessageType('UpdateRuntimeConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPDATERUNTIMECONFIGRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.UpdateRuntimeConfigResponse)
  ))
_sym_db.RegisterMessage(UpdateRuntimeConfigResponse)

RuntimeCondition = _reflection.GeneratedProtocolMessageType('RuntimeCondition', (_message.Message,), dict(
  DESCRIPTOR = _RUNTIMECONDITION,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RuntimeCondition)
  ))
_sym_db.RegisterMessage(RuntimeCondition)

RuntimeStatus = _reflection.GeneratedProtocolMessageType('RuntimeStatus', (_message.Message,), dict(
  DESCRIPTOR = _RUNTIMESTATUS,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RuntimeStatus)
  ))
_sym_db.RegisterMessage(RuntimeStatus)

StatusRequest = _reflection.GeneratedProtocolMessageType('StatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _STATUSREQUEST,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.StatusRequest)
  ))
_sym_db.RegisterMessage(StatusRequest)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATUSRESPONSE,
  __module__ = 'api_pb2'
  # @@protoc_insertion_point(class_scope:runtime.StatusResponse)
  ))
_sym_db.RegisterMessage(StatusResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\330\341\036\000\200\342\036\001\310\341\036\001\310\342\036\001\340\342\036\001\320\342\036\001\220\343\036\000'))
_PODSANDBOXCONFIG_LABELSENTRY.has_options = True
_PODSANDBOXCONFIG_LABELSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_PODSANDBOXCONFIG_ANNOTATIONSENTRY.has_options = True
_PODSANDBOXCONFIG_ANNOTATIONSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_PODSANDBOXSTATUS_LABELSENTRY.has_options = True
_PODSANDBOXSTATUS_LABELSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_PODSANDBOXSTATUS_ANNOTATIONSENTRY.has_options = True
_PODSANDBOXSTATUS_ANNOTATIONSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_PODSANDBOXFILTER_LABELSELECTORENTRY.has_options = True
_PODSANDBOXFILTER_LABELSELECTORENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_PODSANDBOX_LABELSENTRY.has_options = True
_PODSANDBOX_LABELSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_PODSANDBOX_ANNOTATIONSENTRY.has_options = True
_PODSANDBOX_ANNOTATIONSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CONTAINERCONFIG_LABELSENTRY.has_options = True
_CONTAINERCONFIG_LABELSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CONTAINERCONFIG_ANNOTATIONSENTRY.has_options = True
_CONTAINERCONFIG_ANNOTATIONSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CONTAINERFILTER_LABELSELECTORENTRY.has_options = True
_CONTAINERFILTER_LABELSELECTORENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CONTAINER_LABELSENTRY.has_options = True
_CONTAINER_LABELSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CONTAINER_ANNOTATIONSENTRY.has_options = True
_CONTAINER_ANNOTATIONSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CONTAINERSTATUS_LABELSENTRY.has_options = True
_CONTAINERSTATUS_LABELSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CONTAINERSTATUS_ANNOTATIONSENTRY.has_options = True
_CONTAINERSTATUS_ANNOTATIONSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces


  class RuntimeServiceStub(object):
    """Runtime service defines the public APIs for remote container runtimes
    """

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.Version = channel.unary_unary(
          '/runtime.RuntimeService/Version',
          request_serializer=VersionRequest.SerializeToString,
          response_deserializer=VersionResponse.FromString,
          )
      self.RunPodSandbox = channel.unary_unary(
          '/runtime.RuntimeService/RunPodSandbox',
          request_serializer=RunPodSandboxRequest.SerializeToString,
          response_deserializer=RunPodSandboxResponse.FromString,
          )
      self.StopPodSandbox = channel.unary_unary(
          '/runtime.RuntimeService/StopPodSandbox',
          request_serializer=StopPodSandboxRequest.SerializeToString,
          response_deserializer=StopPodSandboxResponse.FromString,
          )
      self.RemovePodSandbox = channel.unary_unary(
          '/runtime.RuntimeService/RemovePodSandbox',
          request_serializer=RemovePodSandboxRequest.SerializeToString,
          response_deserializer=RemovePodSandboxResponse.FromString,
          )
      self.PodSandboxStatus = channel.unary_unary(
          '/runtime.RuntimeService/PodSandboxStatus',
          request_serializer=PodSandboxStatusRequest.SerializeToString,
          response_deserializer=PodSandboxStatusResponse.FromString,
          )
      self.ListPodSandbox = channel.unary_unary(
          '/runtime.RuntimeService/ListPodSandbox',
          request_serializer=ListPodSandboxRequest.SerializeToString,
          response_deserializer=ListPodSandboxResponse.FromString,
          )
      self.CreateContainer = channel.unary_unary(
          '/runtime.RuntimeService/CreateContainer',
          request_serializer=CreateContainerRequest.SerializeToString,
          response_deserializer=CreateContainerResponse.FromString,
          )
      self.StartContainer = channel.unary_unary(
          '/runtime.RuntimeService/StartContainer',
          request_serializer=StartContainerRequest.SerializeToString,
          response_deserializer=StartContainerResponse.FromString,
          )
      self.StopContainer = channel.unary_unary(
          '/runtime.RuntimeService/StopContainer',
          request_serializer=StopContainerRequest.SerializeToString,
          response_deserializer=StopContainerResponse.FromString,
          )
      self.RemoveContainer = channel.unary_unary(
          '/runtime.RuntimeService/RemoveContainer',
          request_serializer=RemoveContainerRequest.SerializeToString,
          response_deserializer=RemoveContainerResponse.FromString,
          )
      self.ListContainers = channel.unary_unary(
          '/runtime.RuntimeService/ListContainers',
          request_serializer=ListContainersRequest.SerializeToString,
          response_deserializer=ListContainersResponse.FromString,
          )
      self.ContainerStatus = channel.unary_unary(
          '/runtime.RuntimeService/ContainerStatus',
          request_serializer=ContainerStatusRequest.SerializeToString,
          response_deserializer=ContainerStatusResponse.FromString,
          )
      self.ExecSync = channel.unary_unary(
          '/runtime.RuntimeService/ExecSync',
          request_serializer=ExecSyncRequest.SerializeToString,
          response_deserializer=ExecSyncResponse.FromString,
          )
      self.Exec = channel.unary_unary(
          '/runtime.RuntimeService/Exec',
          request_serializer=ExecRequest.SerializeToString,
          response_deserializer=ExecResponse.FromString,
          )
      self.Attach = channel.unary_unary(
          '/runtime.RuntimeService/Attach',
          request_serializer=AttachRequest.SerializeToString,
          response_deserializer=AttachResponse.FromString,
          )
      self.PortForward = channel.unary_unary(
          '/runtime.RuntimeService/PortForward',
          request_serializer=PortForwardRequest.SerializeToString,
          response_deserializer=PortForwardResponse.FromString,
          )
      self.UpdateRuntimeConfig = channel.unary_unary(
          '/runtime.RuntimeService/UpdateRuntimeConfig',
          request_serializer=UpdateRuntimeConfigRequest.SerializeToString,
          response_deserializer=UpdateRuntimeConfigResponse.FromString,
          )
      self.Status = channel.unary_unary(
          '/runtime.RuntimeService/Status',
          request_serializer=StatusRequest.SerializeToString,
          response_deserializer=StatusResponse.FromString,
          )


  class RuntimeServiceServicer(object):
    """Runtime service defines the public APIs for remote container runtimes
    """

    def Version(self, request, context):
      """Version returns the runtime name, runtime version, and runtime API version.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def RunPodSandbox(self, request, context):
      """RunPodSandbox creates and starts a pod-level sandbox. Runtimes must ensure
      the sandbox is in the ready state on success.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def StopPodSandbox(self, request, context):
      """StopPodSandbox stops any running process that is part of the sandbox and
      reclaims network resources (e.g., IP addresses) allocated to the sandbox.
      If there are any running containers in the sandbox, they must be forcibly
      terminated.
      This call is idempotent, and must not return an error if all relevant
      resources have already been reclaimed. kubelet will call StopPodSandbox
      at least once before calling RemovePodSandbox. It will also attempt to
      reclaim resources eagerly, as soon as a sandbox is not needed. Hence,
      multiple StopPodSandbox calls are expected.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def RemovePodSandbox(self, request, context):
      """RemovePodSandbox removes the sandbox. If there are any running containers
      in the sandbox, they must be forcibly terminated and removed.
      This call is idempotent, and must not return an error if the sandbox has
      already been removed.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def PodSandboxStatus(self, request, context):
      """PodSandboxStatus returns the status of the PodSandbox.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def ListPodSandbox(self, request, context):
      """ListPodSandbox returns a list of PodSandboxes.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def CreateContainer(self, request, context):
      """CreateContainer creates a new container in specified PodSandbox
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def StartContainer(self, request, context):
      """StartContainer starts the container.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def StopContainer(self, request, context):
      """StopContainer stops a running container with a grace period (i.e., timeout).
      This call is idempotent, and must not return an error if the container has
      already been stopped.
      TODO: what must the runtime do after the grace period is reached?
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def RemoveContainer(self, request, context):
      """RemoveContainer removes the container. If the container is running, the
      container must be forcibly removed.
      This call is idempotent, and must not return an error if the container has
      already been removed.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def ListContainers(self, request, context):
      """ListContainers lists all containers by filters.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def ContainerStatus(self, request, context):
      """ContainerStatus returns status of the container.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def ExecSync(self, request, context):
      """ExecSync runs a command in a container synchronously.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Exec(self, request, context):
      """Exec prepares a streaming endpoint to execute a command in the container.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Attach(self, request, context):
      """Attach prepares a streaming endpoint to attach to a running container.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def PortForward(self, request, context):
      """PortForward prepares a streaming endpoint to forward ports from a PodSandbox.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def UpdateRuntimeConfig(self, request, context):
      """UpdateRuntimeConfig updates the runtime configuration based on the given request.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def Status(self, request, context):
      """Status returns the status of the runtime.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_RuntimeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'Version': grpc.unary_unary_rpc_method_handler(
            servicer.Version,
            request_deserializer=VersionRequest.FromString,
            response_serializer=VersionResponse.SerializeToString,
        ),
        'RunPodSandbox': grpc.unary_unary_rpc_method_handler(
            servicer.RunPodSandbox,
            request_deserializer=RunPodSandboxRequest.FromString,
            response_serializer=RunPodSandboxResponse.SerializeToString,
        ),
        'StopPodSandbox': grpc.unary_unary_rpc_method_handler(
            servicer.StopPodSandbox,
            request_deserializer=StopPodSandboxRequest.FromString,
            response_serializer=StopPodSandboxResponse.SerializeToString,
        ),
        'RemovePodSandbox': grpc.unary_unary_rpc_method_handler(
            servicer.RemovePodSandbox,
            request_deserializer=RemovePodSandboxRequest.FromString,
            response_serializer=RemovePodSandboxResponse.SerializeToString,
        ),
        'PodSandboxStatus': grpc.unary_unary_rpc_method_handler(
            servicer.PodSandboxStatus,
            request_deserializer=PodSandboxStatusRequest.FromString,
            response_serializer=PodSandboxStatusResponse.SerializeToString,
        ),
        'ListPodSandbox': grpc.unary_unary_rpc_method_handler(
            servicer.ListPodSandbox,
            request_deserializer=ListPodSandboxRequest.FromString,
            response_serializer=ListPodSandboxResponse.SerializeToString,
        ),
        'CreateContainer': grpc.unary_unary_rpc_method_handler(
            servicer.CreateContainer,
            request_deserializer=CreateContainerRequest.FromString,
            response_serializer=CreateContainerResponse.SerializeToString,
        ),
        'StartContainer': grpc.unary_unary_rpc_method_handler(
            servicer.StartContainer,
            request_deserializer=StartContainerRequest.FromString,
            response_serializer=StartContainerResponse.SerializeToString,
        ),
        'StopContainer': grpc.unary_unary_rpc_method_handler(
            servicer.StopContainer,
            request_deserializer=StopContainerRequest.FromString,
            response_serializer=StopContainerResponse.SerializeToString,
        ),
        'RemoveContainer': grpc.unary_unary_rpc_method_handler(
            servicer.RemoveContainer,
            request_deserializer=RemoveContainerRequest.FromString,
            response_serializer=RemoveContainerResponse.SerializeToString,
        ),
        'ListContainers': grpc.unary_unary_rpc_method_handler(
            servicer.ListContainers,
            request_deserializer=ListContainersRequest.FromString,
            response_serializer=ListContainersResponse.SerializeToString,
        ),
        'ContainerStatus': grpc.unary_unary_rpc_method_handler(
            servicer.ContainerStatus,
            request_deserializer=ContainerStatusRequest.FromString,
            response_serializer=ContainerStatusResponse.SerializeToString,
        ),
        'ExecSync': grpc.unary_unary_rpc_method_handler(
            servicer.ExecSync,
            request_deserializer=ExecSyncRequest.FromString,
            response_serializer=ExecSyncResponse.SerializeToString,
        ),
        'Exec': grpc.unary_unary_rpc_method_handler(
            servicer.Exec,
            request_deserializer=ExecRequest.FromString,
            response_serializer=ExecResponse.SerializeToString,
        ),
        'Attach': grpc.unary_unary_rpc_method_handler(
            servicer.Attach,
            request_deserializer=AttachRequest.FromString,
            response_serializer=AttachResponse.SerializeToString,
        ),
        'PortForward': grpc.unary_unary_rpc_method_handler(
            servicer.PortForward,
            request_deserializer=PortForwardRequest.FromString,
            response_serializer=PortForwardResponse.SerializeToString,
        ),
        'UpdateRuntimeConfig': grpc.unary_unary_rpc_method_handler(
            servicer.UpdateRuntimeConfig,
            request_deserializer=UpdateRuntimeConfigRequest.FromString,
            response_serializer=UpdateRuntimeConfigResponse.SerializeToString,
        ),
        'Status': grpc.unary_unary_rpc_method_handler(
            servicer.Status,
            request_deserializer=StatusRequest.FromString,
            response_serializer=StatusResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'runtime.RuntimeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class ImageServiceStub(object):
    """ImageService defines the public APIs for managing images.
    """

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.ListImages = channel.unary_unary(
          '/runtime.ImageService/ListImages',
          request_serializer=ListImagesRequest.SerializeToString,
          response_deserializer=ListImagesResponse.FromString,
          )
      self.ImageStatus = channel.unary_unary(
          '/runtime.ImageService/ImageStatus',
          request_serializer=ImageStatusRequest.SerializeToString,
          response_deserializer=ImageStatusResponse.FromString,
          )
      self.PullImage = channel.unary_unary(
          '/runtime.ImageService/PullImage',
          request_serializer=PullImageRequest.SerializeToString,
          response_deserializer=PullImageResponse.FromString,
          )
      self.RemoveImage = channel.unary_unary(
          '/runtime.ImageService/RemoveImage',
          request_serializer=RemoveImageRequest.SerializeToString,
          response_deserializer=RemoveImageResponse.FromString,
          )


  class ImageServiceServicer(object):
    """ImageService defines the public APIs for managing images.
    """

    def ListImages(self, request, context):
      """ListImages lists existing images.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def ImageStatus(self, request, context):
      """ImageStatus returns the status of the image. If the image is not
      present, returns a response with ImageStatusResponse.Image set to
      nil.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def PullImage(self, request, context):
      """PullImage pulls an image with authentication config.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def RemoveImage(self, request, context):
      """RemoveImage removes the image.
      This call is idempotent, and must not return an error if the image has
      already been removed.
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_ImageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'ListImages': grpc.unary_unary_rpc_method_handler(
            servicer.ListImages,
            request_deserializer=ListImagesRequest.FromString,
            response_serializer=ListImagesResponse.SerializeToString,
        ),
        'ImageStatus': grpc.unary_unary_rpc_method_handler(
            servicer.ImageStatus,
            request_deserializer=ImageStatusRequest.FromString,
            response_serializer=ImageStatusResponse.SerializeToString,
        ),
        'PullImage': grpc.unary_unary_rpc_method_handler(
            servicer.PullImage,
            request_deserializer=PullImageRequest.FromString,
            response_serializer=PullImageResponse.SerializeToString,
        ),
        'RemoveImage': grpc.unary_unary_rpc_method_handler(
            servicer.RemoveImage,
            request_deserializer=RemoveImageRequest.FromString,
            response_serializer=RemoveImageResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'runtime.ImageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class BetaRuntimeServiceServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """Runtime service defines the public APIs for remote container runtimes
    """
    def Version(self, request, context):
      """Version returns the runtime name, runtime version, and runtime API version.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def RunPodSandbox(self, request, context):
      """RunPodSandbox creates and starts a pod-level sandbox. Runtimes must ensure
      the sandbox is in the ready state on success.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def StopPodSandbox(self, request, context):
      """StopPodSandbox stops any running process that is part of the sandbox and
      reclaims network resources (e.g., IP addresses) allocated to the sandbox.
      If there are any running containers in the sandbox, they must be forcibly
      terminated.
      This call is idempotent, and must not return an error if all relevant
      resources have already been reclaimed. kubelet will call StopPodSandbox
      at least once before calling RemovePodSandbox. It will also attempt to
      reclaim resources eagerly, as soon as a sandbox is not needed. Hence,
      multiple StopPodSandbox calls are expected.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def RemovePodSandbox(self, request, context):
      """RemovePodSandbox removes the sandbox. If there are any running containers
      in the sandbox, they must be forcibly terminated and removed.
      This call is idempotent, and must not return an error if the sandbox has
      already been removed.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def PodSandboxStatus(self, request, context):
      """PodSandboxStatus returns the status of the PodSandbox.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def ListPodSandbox(self, request, context):
      """ListPodSandbox returns a list of PodSandboxes.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def CreateContainer(self, request, context):
      """CreateContainer creates a new container in specified PodSandbox
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def StartContainer(self, request, context):
      """StartContainer starts the container.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def StopContainer(self, request, context):
      """StopContainer stops a running container with a grace period (i.e., timeout).
      This call is idempotent, and must not return an error if the container has
      already been stopped.
      TODO: what must the runtime do after the grace period is reached?
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def RemoveContainer(self, request, context):
      """RemoveContainer removes the container. If the container is running, the
      container must be forcibly removed.
      This call is idempotent, and must not return an error if the container has
      already been removed.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def ListContainers(self, request, context):
      """ListContainers lists all containers by filters.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def ContainerStatus(self, request, context):
      """ContainerStatus returns status of the container.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def ExecSync(self, request, context):
      """ExecSync runs a command in a container synchronously.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Exec(self, request, context):
      """Exec prepares a streaming endpoint to execute a command in the container.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Attach(self, request, context):
      """Attach prepares a streaming endpoint to attach to a running container.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def PortForward(self, request, context):
      """PortForward prepares a streaming endpoint to forward ports from a PodSandbox.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def UpdateRuntimeConfig(self, request, context):
      """UpdateRuntimeConfig updates the runtime configuration based on the given request.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def Status(self, request, context):
      """Status returns the status of the runtime.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaRuntimeServiceStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """Runtime service defines the public APIs for remote container runtimes
    """
    def Version(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Version returns the runtime name, runtime version, and runtime API version.
      """
      raise NotImplementedError()
    Version.future = None
    def RunPodSandbox(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """RunPodSandbox creates and starts a pod-level sandbox. Runtimes must ensure
      the sandbox is in the ready state on success.
      """
      raise NotImplementedError()
    RunPodSandbox.future = None
    def StopPodSandbox(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """StopPodSandbox stops any running process that is part of the sandbox and
      reclaims network resources (e.g., IP addresses) allocated to the sandbox.
      If there are any running containers in the sandbox, they must be forcibly
      terminated.
      This call is idempotent, and must not return an error if all relevant
      resources have already been reclaimed. kubelet will call StopPodSandbox
      at least once before calling RemovePodSandbox. It will also attempt to
      reclaim resources eagerly, as soon as a sandbox is not needed. Hence,
      multiple StopPodSandbox calls are expected.
      """
      raise NotImplementedError()
    StopPodSandbox.future = None
    def RemovePodSandbox(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """RemovePodSandbox removes the sandbox. If there are any running containers
      in the sandbox, they must be forcibly terminated and removed.
      This call is idempotent, and must not return an error if the sandbox has
      already been removed.
      """
      raise NotImplementedError()
    RemovePodSandbox.future = None
    def PodSandboxStatus(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """PodSandboxStatus returns the status of the PodSandbox.
      """
      raise NotImplementedError()
    PodSandboxStatus.future = None
    def ListPodSandbox(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """ListPodSandbox returns a list of PodSandboxes.
      """
      raise NotImplementedError()
    ListPodSandbox.future = None
    def CreateContainer(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """CreateContainer creates a new container in specified PodSandbox
      """
      raise NotImplementedError()
    CreateContainer.future = None
    def StartContainer(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """StartContainer starts the container.
      """
      raise NotImplementedError()
    StartContainer.future = None
    def StopContainer(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """StopContainer stops a running container with a grace period (i.e., timeout).
      This call is idempotent, and must not return an error if the container has
      already been stopped.
      TODO: what must the runtime do after the grace period is reached?
      """
      raise NotImplementedError()
    StopContainer.future = None
    def RemoveContainer(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """RemoveContainer removes the container. If the container is running, the
      container must be forcibly removed.
      This call is idempotent, and must not return an error if the container has
      already been removed.
      """
      raise NotImplementedError()
    RemoveContainer.future = None
    def ListContainers(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """ListContainers lists all containers by filters.
      """
      raise NotImplementedError()
    ListContainers.future = None
    def ContainerStatus(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """ContainerStatus returns status of the container.
      """
      raise NotImplementedError()
    ContainerStatus.future = None
    def ExecSync(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """ExecSync runs a command in a container synchronously.
      """
      raise NotImplementedError()
    ExecSync.future = None
    def Exec(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Exec prepares a streaming endpoint to execute a command in the container.
      """
      raise NotImplementedError()
    Exec.future = None
    def Attach(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Attach prepares a streaming endpoint to attach to a running container.
      """
      raise NotImplementedError()
    Attach.future = None
    def PortForward(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """PortForward prepares a streaming endpoint to forward ports from a PodSandbox.
      """
      raise NotImplementedError()
    PortForward.future = None
    def UpdateRuntimeConfig(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """UpdateRuntimeConfig updates the runtime configuration based on the given request.
      """
      raise NotImplementedError()
    UpdateRuntimeConfig.future = None
    def Status(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Status returns the status of the runtime.
      """
      raise NotImplementedError()
    Status.future = None


  def beta_create_RuntimeService_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('runtime.RuntimeService', 'Attach'): AttachRequest.FromString,
      ('runtime.RuntimeService', 'ContainerStatus'): ContainerStatusRequest.FromString,
      ('runtime.RuntimeService', 'CreateContainer'): CreateContainerRequest.FromString,
      ('runtime.RuntimeService', 'Exec'): ExecRequest.FromString,
      ('runtime.RuntimeService', 'ExecSync'): ExecSyncRequest.FromString,
      ('runtime.RuntimeService', 'ListContainers'): ListContainersRequest.FromString,
      ('runtime.RuntimeService', 'ListPodSandbox'): ListPodSandboxRequest.FromString,
      ('runtime.RuntimeService', 'PodSandboxStatus'): PodSandboxStatusRequest.FromString,
      ('runtime.RuntimeService', 'PortForward'): PortForwardRequest.FromString,
      ('runtime.RuntimeService', 'RemoveContainer'): RemoveContainerRequest.FromString,
      ('runtime.RuntimeService', 'RemovePodSandbox'): RemovePodSandboxRequest.FromString,
      ('runtime.RuntimeService', 'RunPodSandbox'): RunPodSandboxRequest.FromString,
      ('runtime.RuntimeService', 'StartContainer'): StartContainerRequest.FromString,
      ('runtime.RuntimeService', 'Status'): StatusRequest.FromString,
      ('runtime.RuntimeService', 'StopContainer'): StopContainerRequest.FromString,
      ('runtime.RuntimeService', 'StopPodSandbox'): StopPodSandboxRequest.FromString,
      ('runtime.RuntimeService', 'UpdateRuntimeConfig'): UpdateRuntimeConfigRequest.FromString,
      ('runtime.RuntimeService', 'Version'): VersionRequest.FromString,
    }
    response_serializers = {
      ('runtime.RuntimeService', 'Attach'): AttachResponse.SerializeToString,
      ('runtime.RuntimeService', 'ContainerStatus'): ContainerStatusResponse.SerializeToString,
      ('runtime.RuntimeService', 'CreateContainer'): CreateContainerResponse.SerializeToString,
      ('runtime.RuntimeService', 'Exec'): ExecResponse.SerializeToString,
      ('runtime.RuntimeService', 'ExecSync'): ExecSyncResponse.SerializeToString,
      ('runtime.RuntimeService', 'ListContainers'): ListContainersResponse.SerializeToString,
      ('runtime.RuntimeService', 'ListPodSandbox'): ListPodSandboxResponse.SerializeToString,
      ('runtime.RuntimeService', 'PodSandboxStatus'): PodSandboxStatusResponse.SerializeToString,
      ('runtime.RuntimeService', 'PortForward'): PortForwardResponse.SerializeToString,
      ('runtime.RuntimeService', 'RemoveContainer'): RemoveContainerResponse.SerializeToString,
      ('runtime.RuntimeService', 'RemovePodSandbox'): RemovePodSandboxResponse.SerializeToString,
      ('runtime.RuntimeService', 'RunPodSandbox'): RunPodSandboxResponse.SerializeToString,
      ('runtime.RuntimeService', 'StartContainer'): StartContainerResponse.SerializeToString,
      ('runtime.RuntimeService', 'Status'): StatusResponse.SerializeToString,
      ('runtime.RuntimeService', 'StopContainer'): StopContainerResponse.SerializeToString,
      ('runtime.RuntimeService', 'StopPodSandbox'): StopPodSandboxResponse.SerializeToString,
      ('runtime.RuntimeService', 'UpdateRuntimeConfig'): UpdateRuntimeConfigResponse.SerializeToString,
      ('runtime.RuntimeService', 'Version'): VersionResponse.SerializeToString,
    }
    method_implementations = {
      ('runtime.RuntimeService', 'Attach'): face_utilities.unary_unary_inline(servicer.Attach),
      ('runtime.RuntimeService', 'ContainerStatus'): face_utilities.unary_unary_inline(servicer.ContainerStatus),
      ('runtime.RuntimeService', 'CreateContainer'): face_utilities.unary_unary_inline(servicer.CreateContainer),
      ('runtime.RuntimeService', 'Exec'): face_utilities.unary_unary_inline(servicer.Exec),
      ('runtime.RuntimeService', 'ExecSync'): face_utilities.unary_unary_inline(servicer.ExecSync),
      ('runtime.RuntimeService', 'ListContainers'): face_utilities.unary_unary_inline(servicer.ListContainers),
      ('runtime.RuntimeService', 'ListPodSandbox'): face_utilities.unary_unary_inline(servicer.ListPodSandbox),
      ('runtime.RuntimeService', 'PodSandboxStatus'): face_utilities.unary_unary_inline(servicer.PodSandboxStatus),
      ('runtime.RuntimeService', 'PortForward'): face_utilities.unary_unary_inline(servicer.PortForward),
      ('runtime.RuntimeService', 'RemoveContainer'): face_utilities.unary_unary_inline(servicer.RemoveContainer),
      ('runtime.RuntimeService', 'RemovePodSandbox'): face_utilities.unary_unary_inline(servicer.RemovePodSandbox),
      ('runtime.RuntimeService', 'RunPodSandbox'): face_utilities.unary_unary_inline(servicer.RunPodSandbox),
      ('runtime.RuntimeService', 'StartContainer'): face_utilities.unary_unary_inline(servicer.StartContainer),
      ('runtime.RuntimeService', 'Status'): face_utilities.unary_unary_inline(servicer.Status),
      ('runtime.RuntimeService', 'StopContainer'): face_utilities.unary_unary_inline(servicer.StopContainer),
      ('runtime.RuntimeService', 'StopPodSandbox'): face_utilities.unary_unary_inline(servicer.StopPodSandbox),
      ('runtime.RuntimeService', 'UpdateRuntimeConfig'): face_utilities.unary_unary_inline(servicer.UpdateRuntimeConfig),
      ('runtime.RuntimeService', 'Version'): face_utilities.unary_unary_inline(servicer.Version),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_RuntimeService_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('runtime.RuntimeService', 'Attach'): AttachRequest.SerializeToString,
      ('runtime.RuntimeService', 'ContainerStatus'): ContainerStatusRequest.SerializeToString,
      ('runtime.RuntimeService', 'CreateContainer'): CreateContainerRequest.SerializeToString,
      ('runtime.RuntimeService', 'Exec'): ExecRequest.SerializeToString,
      ('runtime.RuntimeService', 'ExecSync'): ExecSyncRequest.SerializeToString,
      ('runtime.RuntimeService', 'ListContainers'): ListContainersRequest.SerializeToString,
      ('runtime.RuntimeService', 'ListPodSandbox'): ListPodSandboxRequest.SerializeToString,
      ('runtime.RuntimeService', 'PodSandboxStatus'): PodSandboxStatusRequest.SerializeToString,
      ('runtime.RuntimeService', 'PortForward'): PortForwardRequest.SerializeToString,
      ('runtime.RuntimeService', 'RemoveContainer'): RemoveContainerRequest.SerializeToString,
      ('runtime.RuntimeService', 'RemovePodSandbox'): RemovePodSandboxRequest.SerializeToString,
      ('runtime.RuntimeService', 'RunPodSandbox'): RunPodSandboxRequest.SerializeToString,
      ('runtime.RuntimeService', 'StartContainer'): StartContainerRequest.SerializeToString,
      ('runtime.RuntimeService', 'Status'): StatusRequest.SerializeToString,
      ('runtime.RuntimeService', 'StopContainer'): StopContainerRequest.SerializeToString,
      ('runtime.RuntimeService', 'StopPodSandbox'): StopPodSandboxRequest.SerializeToString,
      ('runtime.RuntimeService', 'UpdateRuntimeConfig'): UpdateRuntimeConfigRequest.SerializeToString,
      ('runtime.RuntimeService', 'Version'): VersionRequest.SerializeToString,
    }
    response_deserializers = {
      ('runtime.RuntimeService', 'Attach'): AttachResponse.FromString,
      ('runtime.RuntimeService', 'ContainerStatus'): ContainerStatusResponse.FromString,
      ('runtime.RuntimeService', 'CreateContainer'): CreateContainerResponse.FromString,
      ('runtime.RuntimeService', 'Exec'): ExecResponse.FromString,
      ('runtime.RuntimeService', 'ExecSync'): ExecSyncResponse.FromString,
      ('runtime.RuntimeService', 'ListContainers'): ListContainersResponse.FromString,
      ('runtime.RuntimeService', 'ListPodSandbox'): ListPodSandboxResponse.FromString,
      ('runtime.RuntimeService', 'PodSandboxStatus'): PodSandboxStatusResponse.FromString,
      ('runtime.RuntimeService', 'PortForward'): PortForwardResponse.FromString,
      ('runtime.RuntimeService', 'RemoveContainer'): RemoveContainerResponse.FromString,
      ('runtime.RuntimeService', 'RemovePodSandbox'): RemovePodSandboxResponse.FromString,
      ('runtime.RuntimeService', 'RunPodSandbox'): RunPodSandboxResponse.FromString,
      ('runtime.RuntimeService', 'StartContainer'): StartContainerResponse.FromString,
      ('runtime.RuntimeService', 'Status'): StatusResponse.FromString,
      ('runtime.RuntimeService', 'StopContainer'): StopContainerResponse.FromString,
      ('runtime.RuntimeService', 'StopPodSandbox'): StopPodSandboxResponse.FromString,
      ('runtime.RuntimeService', 'UpdateRuntimeConfig'): UpdateRuntimeConfigResponse.FromString,
      ('runtime.RuntimeService', 'Version'): VersionResponse.FromString,
    }
    cardinalities = {
      'Attach': cardinality.Cardinality.UNARY_UNARY,
      'ContainerStatus': cardinality.Cardinality.UNARY_UNARY,
      'CreateContainer': cardinality.Cardinality.UNARY_UNARY,
      'Exec': cardinality.Cardinality.UNARY_UNARY,
      'ExecSync': cardinality.Cardinality.UNARY_UNARY,
      'ListContainers': cardinality.Cardinality.UNARY_UNARY,
      'ListPodSandbox': cardinality.Cardinality.UNARY_UNARY,
      'PodSandboxStatus': cardinality.Cardinality.UNARY_UNARY,
      'PortForward': cardinality.Cardinality.UNARY_UNARY,
      'RemoveContainer': cardinality.Cardinality.UNARY_UNARY,
      'RemovePodSandbox': cardinality.Cardinality.UNARY_UNARY,
      'RunPodSandbox': cardinality.Cardinality.UNARY_UNARY,
      'StartContainer': cardinality.Cardinality.UNARY_UNARY,
      'Status': cardinality.Cardinality.UNARY_UNARY,
      'StopContainer': cardinality.Cardinality.UNARY_UNARY,
      'StopPodSandbox': cardinality.Cardinality.UNARY_UNARY,
      'UpdateRuntimeConfig': cardinality.Cardinality.UNARY_UNARY,
      'Version': cardinality.Cardinality.UNARY_UNARY,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'runtime.RuntimeService', cardinalities, options=stub_options)


  class BetaImageServiceServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """ImageService defines the public APIs for managing images.
    """
    def ListImages(self, request, context):
      """ListImages lists existing images.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def ImageStatus(self, request, context):
      """ImageStatus returns the status of the image. If the image is not
      present, returns a response with ImageStatusResponse.Image set to
      nil.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def PullImage(self, request, context):
      """PullImage pulls an image with authentication config.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def RemoveImage(self, request, context):
      """RemoveImage removes the image.
      This call is idempotent, and must not return an error if the image has
      already been removed.
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaImageServiceStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """ImageService defines the public APIs for managing images.
    """
    def ListImages(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """ListImages lists existing images.
      """
      raise NotImplementedError()
    ListImages.future = None
    def ImageStatus(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """ImageStatus returns the status of the image. If the image is not
      present, returns a response with ImageStatusResponse.Image set to
      nil.
      """
      raise NotImplementedError()
    ImageStatus.future = None
    def PullImage(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """PullImage pulls an image with authentication config.
      """
      raise NotImplementedError()
    PullImage.future = None
    def RemoveImage(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """RemoveImage removes the image.
      This call is idempotent, and must not return an error if the image has
      already been removed.
      """
      raise NotImplementedError()
    RemoveImage.future = None


  def beta_create_ImageService_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('runtime.ImageService', 'ImageStatus'): ImageStatusRequest.FromString,
      ('runtime.ImageService', 'ListImages'): ListImagesRequest.FromString,
      ('runtime.ImageService', 'PullImage'): PullImageRequest.FromString,
      ('runtime.ImageService', 'RemoveImage'): RemoveImageRequest.FromString,
    }
    response_serializers = {
      ('runtime.ImageService', 'ImageStatus'): ImageStatusResponse.SerializeToString,
      ('runtime.ImageService', 'ListImages'): ListImagesResponse.SerializeToString,
      ('runtime.ImageService', 'PullImage'): PullImageResponse.SerializeToString,
      ('runtime.ImageService', 'RemoveImage'): RemoveImageResponse.SerializeToString,
    }
    method_implementations = {
      ('runtime.ImageService', 'ImageStatus'): face_utilities.unary_unary_inline(servicer.ImageStatus),
      ('runtime.ImageService', 'ListImages'): face_utilities.unary_unary_inline(servicer.ListImages),
      ('runtime.ImageService', 'PullImage'): face_utilities.unary_unary_inline(servicer.PullImage),
      ('runtime.ImageService', 'RemoveImage'): face_utilities.unary_unary_inline(servicer.RemoveImage),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_ImageService_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('runtime.ImageService', 'ImageStatus'): ImageStatusRequest.SerializeToString,
      ('runtime.ImageService', 'ListImages'): ListImagesRequest.SerializeToString,
      ('runtime.ImageService', 'PullImage'): PullImageRequest.SerializeToString,
      ('runtime.ImageService', 'RemoveImage'): RemoveImageRequest.SerializeToString,
    }
    response_deserializers = {
      ('runtime.ImageService', 'ImageStatus'): ImageStatusResponse.FromString,
      ('runtime.ImageService', 'ListImages'): ListImagesResponse.FromString,
      ('runtime.ImageService', 'PullImage'): PullImageResponse.FromString,
      ('runtime.ImageService', 'RemoveImage'): RemoveImageResponse.FromString,
    }
    cardinalities = {
      'ImageStatus': cardinality.Cardinality.UNARY_UNARY,
      'ListImages': cardinality.Cardinality.UNARY_UNARY,
      'PullImage': cardinality.Cardinality.UNARY_UNARY,
      'RemoveImage': cardinality.Cardinality.UNARY_UNARY,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'runtime.ImageService', cardinalities, options=stub_options)
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)
